<?php
/**
 * Widget: Example
 *
 * @package WordPress
 * @subpackage BaseKit Addons
 * @since v1.0.0
 */

// Load widget
if (!function_exists('basekit_addons_widget_example_load')) {
	add_action( 'widgets_init', 'basekit_addons_widget_example_load' );
	function basekit_addons_widget_example_load() {
		register_widget('trx_addons_widget_example');
	}
}

// Widget Class
class trx_addons_widget_example extends TRX_Addons_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_example',
							'description' => esc_html__('Widget Example - short description', 'basekit-addons'));
		parent::__construct( 'trx_addons_widget_example', esc_html__('ThemeREX Example', 'basekit-addons'), $widget_ops );
	}

	// Show widget
	function widget($args, $instance) {
		$title = apply_filters('widget_title', isset($instance['title']) ? $instance['title'] : '');
		
		$username = isset($instance['username']) ? $instance['username'] : '';
		$description = isset($instance['description']) ? $instance['description'] : '';
		$avatar = isset($instance['avatar']) ? $instance['avatar'] : '';
		if (!empty($avatar)) {
			$avatar = trx_addons_get_attachment_url($avatar, trx_addons_get_thumb_size('avatar'));
			$attr = trx_addons_getimagesize($avatar);
			$avatar = '<img src="'.esc_url($avatar).'" alt="'.esc_attr($username).'"'.(!empty($attr[3]) ? ' '.trim($attr[3]) : '').'>';
		}

		basekit_addons_get_template_part(BASEKIT_ADDONS_PLUGIN_WIDGETS . 'example/tpl.default.php',
									'trx_addons_args_widget_example',
									apply_filters('trx_addons_filter_widget_args',
												array_merge($args, compact('title', 'avatar', 'username', 'description')),
												$instance, 'trx_addons_widget_example')
									);
	}

	// Update the widget settings.
	function update($new_instance, $instance) {
		$instance = array_merge($instance, $new_instance);
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['avatar'] = strip_tags($new_instance['avatar']);
		$instance['username'] = strip_tags($new_instance['username']);
		$instance['description'] = strip_tags($new_instance['description']);
		return apply_filters('trx_addons_filter_widget_args_update', $instance, $new_instance, 'trx_addons_widget_example');
	}

	// Displays the widget settings controls on the widget panel.
	function form($instance) {

		// Set up some default widget settings
		$instance = wp_parse_args( (array) $instance, apply_filters('trx_addons_filter_widget_args_default', array(
			'title' => '',
			'avatar' => '',
			'username' => '',
			'description' => ''
			), 'trx_addons_widget_example')
		);
		
		do_action('trx_addons_action_before_widget_fields', $instance, 'trx_addons_widget_example');
		
		$this->show_field(array('name' => 'title',
								'title' => __('Widget title:', 'basekit-addons'),
								'value' => $instance['title'],
								'type' => 'text'));
		
		do_action('trx_addons_action_after_widget_title', $instance, 'trx_addons_widget_example');

		$this->show_field(array('name' => 'avatar',
								'title' => __('Avatar:', 'basekit-addons'),
								'value' => $instance['avatar'],
								'type' => 'image'));

		$this->show_field(array('name' => 'username',
								'title' => __('User name (if equal to # - not show):', 'basekit-addons'),
								'value' => $instance['username'],
								'type' => 'text'));

		$this->show_field(array('name' => 'description',
								'title' => __('Short description (if equal to # - not show):', 'basekit-addons'),
								'value' => $instance['description'],
								'type' => 'textarea'));
		
		do_action('trx_addons_action_after_widget_fields', $instance, 'trx_addons_widget_example');
	}
}

	
// Load required styles and scripts for the frontend
if ( !function_exists( 'basekit_addons_widget_example_load_scripts_front' ) ) {
	add_action("wp_enqueue_scripts", 'basekit_addons_widget_example_load_scripts_front');
	function basekit_addons_widget_example_load_scripts_front() {
		if (basekit_addons_get_file_dir(BASEKIT_ADDONS_PLUGIN_WIDGETS . 'example/example.css')!='') {
			wp_enqueue_style( 'basekit_addons-widget_example', trx_addons_get_file_url(BASEKIT_ADDONS_PLUGIN_WIDGETS . 'example/example.css'), array(), null );
		}
		if (basekit_addons_get_file_dir(BASEKIT_ADDONS_PLUGIN_WIDGETS . 'example/example.js')!='') {
			wp_enqueue_script('basekit_addons-widget_example', basekit_addons_get_file_url(BASEKIT_ADDONS_PLUGIN_WIDGETS . 'example/example.js'), array('jquery'), null, true );
		}
	}
}



// trx_widget_example
//-------------------------------------------------------------
/*
[trx_widget_example id="unique_id" title="Widget title" avatar="image_url" username="User display name" description="short description"]
*/
if ( !function_exists( 'basekit_addons_sc_widget_example' ) ) {
	function basekit_addons_sc_widget_example($atts, $content=null){	
		$atts = trx_addons_sc_prepare_atts('trx_widget_example', $atts, array(
			// Individual params
			"title" => "",
			"avatar" => "",
			"username" => "",
			"description" => "",
			// Common params
			"id" => "",
			"class" => "",
			"css" => ""
			)
		);
		extract($atts);
		$type = 'trx_addons_widget_example';
		$output = '';
		global $wp_widget_factory;
		if ( is_object( $wp_widget_factory ) && isset( $wp_widget_factory->widgets, $wp_widget_factory->widgets[ $type ] ) ) {
			$output = '<div' . ($id ? ' id="'.esc_attr($id).'"' : '')
							. ' class="widget_area sc_widget_example' 
								. (trx_addons_exists_visual_composer() ? ' vc_widget_example wpb_content_element' : '') 
								. (!empty($class) ? ' ' . esc_attr($class) : '') 
								. '"'
							. ($css ? ' style="'.esc_attr($css).'"' : '')
						. '>';
			ob_start();
			the_widget( $type, $atts, trx_addons_prepare_widgets_args($id ? $id.'_widget' : 'widget_example', 'widget_example') );
			$output .= ob_get_contents();
			ob_end_clean();
			$output .= '</div>';
		}
		return apply_filters('trx_addons_sc_output', $output, 'trx_widget_example', $atts, $content);
	}
}


// Add [trx_widget_aboutme] in the VC shortcodes list
if (!function_exists('basekit_addons_sc_widget_example_add_in_vc')) {
	function basekit_addons_sc_widget_example_add_in_vc() {
		
		add_shortcode("trx_widget_example", "basekit_addons_sc_widget_example");
		
		if (!trx_addons_exists_visual_composer()) return;
		
		vc_lean_map("trx_widget_example", 'basekit_addons_sc_widget_example_add_in_vc_params');
		class WPBakeryShortCode_Trx_Widget_Example extends WPBakeryShortCode {}
	}
	add_action('init', 'basekit_addons_sc_widget_example_add_in_vc', 20);
}

// Return params
if (!function_exists('basekit_addons_sc_widget_example_add_in_vc_params')) {
	function basekit_addons_sc_widget_example_add_in_vc_params() {
		return apply_filters('trx_addons_sc_map', array(
				"base" => "trx_widget_example",
				"name" => esc_html__("Widgets Example", 'basekit-addons'),
				"description" => wp_kses_data( __("Insert widget with user's name, avatar and short description", 'basekit-addons') ),
				"category" => esc_html__('ThemeREX', 'basekit-addons'),
				"icon" => 'icon_trx_widget_example',
				"class" => "trx_widget_example",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array_merge(
					array(
						array(
							"param_name" => "title",
							"heading" => esc_html__("Widget title", 'basekit-addons'),
							"description" => wp_kses_data( __("Title of the widget", 'basekit-addons') ),
							"admin_label" => true,
							"type" => "textfield"
						),
						array(
							"param_name" => "avatar",
							"heading" => esc_html__("Avatar", 'basekit-addons'),
							"description" => wp_kses_data( __("Select or upload image or write URL from other site for user's avatar", 'basekit-addons') ),
							"type" => "attach_image"
						),
						array(
							"param_name" => "username",
							"heading" => esc_html__("User name", 'basekit-addons'),
							"description" => wp_kses_data( __("User display name", 'basekit-addons') ),
							"admin_label" => true,
							"type" => "textfield"
						),
						array(
							"param_name" => "description",
							"heading" => esc_html__("Description", 'basekit-addons'),
							"description" => wp_kses_data( __("Short description about user", 'basekit-addons') ),
							"type" => "textarea"
						)
					),
					trx_addons_vc_add_id_param()
				)
			), 'trx_widget_example' );
	}
}
?>