<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage RUMBLE
 * @since RUMBLE 1.0
 */

$rumble_template_args = get_query_var( 'rumble_template_args' );
if ( is_array( $rumble_template_args ) ) {
	$rumble_columns    = empty( $rumble_template_args['columns'] ) ? 1 : max( 1, min( 3, $rumble_template_args['columns'] ) );
	$rumble_blog_style = array( $rumble_template_args['type'], $rumble_columns );
} else {
	$rumble_blog_style = explode( '_', rumble_get_theme_option( 'blog_style' ) );
	$rumble_columns    = empty( $rumble_blog_style[1] ) ? 1 : max( 1, min( 3, $rumble_blog_style[1] ) );
}
$rumble_expanded    = ! rumble_sidebar_present() && rumble_is_on( rumble_get_theme_option( 'expand_content' ) );
$rumble_post_format = get_post_format();
$rumble_post_format = empty( $rumble_post_format ) ? 'standard' : str_replace( 'post-format-', '', $rumble_post_format );
$rumble_animation   = rumble_get_theme_option( 'blog_animation' );

?><article id="post-<?php the_ID(); ?>" 
									<?php
									post_class(
										'post_item'
										. ' post_layout_chess'
										. ' post_layout_chess_' . esc_attr( $rumble_columns )
										. ' post_format_' . esc_attr( $rumble_post_format )
										. ( ! empty( $rumble_template_args['slider'] ) ? ' slider-slide swiper-slide' : '' )
									);
									echo ( ! rumble_is_off( $rumble_animation ) && empty( $rumble_template_args['slider'] ) ? ' data-animation="' . esc_attr( rumble_get_animation_classes( $rumble_animation ) ) . '"' : '' );
									?>
	>

	<?php
	// Add anchor
	if ( 1 == $rumble_columns && ! is_array( $rumble_template_args ) && shortcode_exists( 'trx_sc_anchor' ) ) {
		echo do_shortcode( '[trx_sc_anchor id="post_' . esc_attr( get_the_ID() ) . '" title="' . the_title_attribute( array( 'echo' => false ) ) . '" icon="' . esc_attr( rumble_get_post_icon() ) . '"]' );
	}

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$rumble_hover = ! empty( $rumble_template_args['hover'] ) && ! rumble_is_inherit( $rumble_template_args['hover'] )
						? $rumble_template_args['hover']
						: rumble_get_theme_option( 'image_hover' );
	rumble_show_post_featured(
		array(
			'class'         => 1 == $rumble_columns && ! is_array( $rumble_template_args ) ? 'rumble-full-height' : '',
			'hover'         => $rumble_hover,
			'no_links'      => ! empty( $rumble_template_args['no_links'] ),
			'show_no_image' => true,
			'thumb_ratio'   => '1:1',
			'thumb_bg'      => true,
			'thumb_size'    => rumble_get_thumb_size(
				strpos( rumble_get_theme_option( 'body_style' ), 'full' ) !== false
										? ( 1 < $rumble_columns ? 'huge' : 'original' )
										: ( 2 < $rumble_columns ? 'big' : 'huge' )
			),
		)
	);

	?>
	<div class="post_inner"><div class="post_inner_content"><div class="post_header entry-header">
		<?php
			do_action( 'rumble_action_before_post_title' );

			// Post title
			if ( empty( $rumble_template_args['no_links'] ) ) {
				the_title( sprintf( '<h3 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h3>' );
			} else {
				the_title( '<h3 class="post_title entry-title">', '</h3>' );
			}

			do_action( 'rumble_action_before_post_meta' );

			// Post meta
			$rumble_components = rumble_array_get_keys_by_value( rumble_get_theme_option( 'meta_parts' ) );
			$rumble_post_meta  = empty( $rumble_components ) || in_array( $rumble_hover, array( 'border', 'pull', 'slide', 'fade' ) )
										? ''
										: rumble_show_post_meta(
											apply_filters(
												'rumble_filter_post_meta_args', array(
													'components' => $rumble_components,
													'seo'  => false,
													'echo' => false,
												), $rumble_blog_style[0], $rumble_columns
											)
										);
			rumble_show_layout( $rumble_post_meta );
			?>
		</div><!-- .entry-header -->

		<div class="post_content entry-content">
			<?php
			// Post content area
			if ( empty( $rumble_template_args['hide_excerpt'] )  && rumble_get_theme_option( 'excerpt_length' ) > 0 ) {
				rumble_show_post_content( $rumble_template_args, '<div class="post_content_inner">', '</div>' );
			}
			// Post meta
			if ( in_array( $rumble_post_format, array( 'link', 'aside', 'status', 'quote' ) ) ) {
				rumble_show_layout( $rumble_post_meta );
			}
			// More button
			if ( empty( $rumble_template_args['no_links'] ) && ! in_array( $rumble_post_format, array( 'link', 'aside', 'status', 'quote' ) ) ) {
				rumble_show_post_more_link( $rumble_template_args, '<p>', '</p>' );
			}
			?>
		</div><!-- .entry-content -->

	</div></div><!-- .post_inner -->

</article><?php
// Need opening PHP-tag above, because <article> is a inline-block element (used as column)!
