<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage RUMBLE
 * @since RUMBLE 1.0
 */

$rumble_template_args = get_query_var( 'rumble_template_args' );
if ( is_array( $rumble_template_args ) ) {
	$rumble_columns    = empty( $rumble_template_args['columns'] ) ? 2 : max( 1, $rumble_template_args['columns'] );
	$rumble_blog_style = array( $rumble_template_args['type'], $rumble_columns );
} else {
	$rumble_blog_style = explode( '_', rumble_get_theme_option( 'blog_style' ) );
	$rumble_columns    = empty( $rumble_blog_style[1] ) ? 2 : max( 1, $rumble_blog_style[1] );
}
$rumble_expanded   = ! rumble_sidebar_present() && rumble_is_on( rumble_get_theme_option( 'expand_content' ) );
$rumble_animation  = rumble_get_theme_option( 'blog_animation' );
$rumble_components = rumble_array_get_keys_by_value( rumble_get_theme_option( 'meta_parts' ) );

$rumble_post_format = get_post_format();
$rumble_post_format = empty( $rumble_post_format ) ? 'standard' : str_replace( 'post-format-', '', $rumble_post_format );

?><div class="
<?php
if ( ! empty( $rumble_template_args['slider'] ) ) {
	echo ' slider-slide swiper-slide';
} else {
	echo ( 'classic' == $rumble_blog_style[0] ? 'column' : 'masonry_item masonry_item' ) . '-1_' . esc_attr( $rumble_columns );
}
?>
"><article id="post-<?php the_ID(); ?>" 
	<?php
		post_class(
			'post_item post_format_' . esc_attr( $rumble_post_format )
					. ' post_layout_classic post_layout_classic_' . esc_attr( $rumble_columns )
					. ' post_layout_' . esc_attr( $rumble_blog_style[0] )
					. ' post_layout_' . esc_attr( $rumble_blog_style[0] ) . '_' . esc_attr( $rumble_columns )
		);
		echo ( ! rumble_is_off( $rumble_animation ) && empty( $rumble_template_args['slider'] ) ? ' data-animation="' . esc_attr( rumble_get_animation_classes( $rumble_animation ) ) . '"' : '' );
		?>
	>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$rumble_hover = ! empty( $rumble_template_args['hover'] ) && ! rumble_is_inherit( $rumble_template_args['hover'] )
						? $rumble_template_args['hover']
						: rumble_get_theme_option( 'image_hover' );
	rumble_show_post_featured(
		array(
			'thumb_size' => rumble_get_thumb_size(
				'classic' == $rumble_blog_style[0]
						? ( strpos( rumble_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $rumble_columns > 2 ? 'big' : 'huge' )
								: ( $rumble_columns > 2
									? ( $rumble_expanded ? 'med' : 'small' )
									: ( $rumble_expanded ? 'big' : 'med' )
									)
							)
						: ( strpos( rumble_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $rumble_columns > 2 ? 'masonry-big' : 'full' )
								: ( $rumble_columns <= 2 && $rumble_expanded ? 'masonry-big' : 'masonry' )
							)
			),
			'hover'      => $rumble_hover,
			'no_links'   => ! empty( $rumble_template_args['no_links'] ),
		)
	);

	if ( ! in_array( $rumble_post_format, array( 'link', 'aside', 'status', 'quote' ) ) ) {
		?>
		<div class="post_header entry-header">
			<?php
			do_action( 'rumble_action_before_post_title' );

			// Post title
			if ( empty( $rumble_template_args['no_links'] ) ) {
				the_title( sprintf( '<h4 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h4>' );
			} else {
				the_title( '<h4 class="post_title entry-title">', '</h4>' );
			}

			do_action( 'rumble_action_before_post_meta' );

			// Post meta
			if ( ! empty( $rumble_components ) && ! in_array( $rumble_hover, array( 'border', 'pull', 'slide', 'fade' ) ) ) {
				rumble_show_post_meta(
					apply_filters(
						'rumble_filter_post_meta_args', array(
							'components' => $rumble_components,
							'seo'        => false,
						), $rumble_blog_style[0], $rumble_columns
					)
				);
			}

			do_action( 'rumble_action_after_post_meta' );
			?>
		</div><!-- .entry-header -->
		<?php
	}
	?>

	<div class="post_content entry-content">
		<?php
		if ( empty( $rumble_template_args['hide_excerpt'] )  && rumble_get_theme_option( 'excerpt_length' ) > 0 ) {
			// Post content area
			rumble_show_post_content( $rumble_template_args, '<div class="post_content_inner">', '</div>' );
		}

		// Post meta
		if ( in_array( $rumble_post_format, array( 'link', 'aside', 'status', 'quote' ) ) ) {
			if ( ! empty( $rumble_components ) ) {
				rumble_show_post_meta(
					apply_filters(
						'rumble_filter_post_meta_args', array(
							'components' => $rumble_components,
						), $rumble_blog_style[0], $rumble_columns
					)
				);
			}
		}
		
		// More button
		if ( empty( $rumble_template_args['no_links'] ) && ! empty( $rumble_template_args['more_text'] ) && ! in_array( $rumble_post_format, array( 'link', 'aside', 'status', 'quote' ) ) ) {
			rumble_show_post_more_link( $rumble_template_args, '<p>', '</p>' );
		}
		?>
	</div><!-- .entry-content -->

</article></div><?php
// Need opening PHP-tag above, because <div> is a inline-block element (used as column)!
