<?php
/**
 * The default template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage RUMBLE
 * @since RUMBLE 1.0
 */

$rumble_template_args = get_query_var( 'rumble_template_args' );
if ( is_array( $rumble_template_args ) ) {
	$rumble_columns    = empty( $rumble_template_args['columns'] ) ? 1 : max( 1, $rumble_template_args['columns'] );
	$rumble_blog_style = array( $rumble_template_args['type'], $rumble_columns );
	if ( ! empty( $rumble_template_args['slider'] ) ) {
		?><div class="slider-slide swiper-slide">
		<?php
	} elseif ( $rumble_columns > 1 ) {
		?>
		<div class="column-1_<?php echo esc_attr( $rumble_columns ); ?>">
		<?php
	}
}
$rumble_expanded    = ! rumble_sidebar_present() && rumble_is_on( rumble_get_theme_option( 'expand_content' ) );
$rumble_post_format = get_post_format();
$rumble_post_format = empty( $rumble_post_format ) ? 'standard' : str_replace( 'post-format-', '', $rumble_post_format );
$rumble_animation   = rumble_get_theme_option( 'blog_animation' );
$rumble_components = rumble_array_get_keys_by_value( rumble_get_theme_option( 'meta_parts' ) );
?>
<article id="post-<?php the_ID(); ?>" 
	<?php post_class( 'post_item post_layout_excerpt post_format_' . esc_attr( $rumble_post_format ) ); ?>
	<?php echo ( ! rumble_is_off( $rumble_animation ) && empty( $rumble_template_args['slider'] ) ? ' data-animation="' . esc_attr( rumble_get_animation_classes( $rumble_animation ) ) . '"' : '' ); ?>
>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$rumble_hover = ! empty( $rumble_template_args['hover'] ) && ! rumble_is_inherit( $rumble_template_args['hover'] )
						? $rumble_template_args['hover']
						: rumble_get_theme_option( 'image_hover' );
	rumble_show_post_featured(
		array(
			'no_links'   => ! empty( $rumble_template_args['no_links'] ),
			'hover'      => $rumble_hover,
			'thumb_size' => rumble_get_thumb_size( strpos( rumble_get_theme_option( 'body_style' ), 'full' ) !== false ? 'full' : ( $rumble_expanded ? 'huge' : 'big' ) ),
		)
	);

	// Title and post meta
	if ( get_the_title() != '' ) {
		?>
		<div class="post_header entry-header">
			<?php

            do_action( 'rumble_action_before_post_meta' );

			// Post meta

			if ( ! empty( $rumble_components ) && ($rumble_post_format !== 'quote') && ! in_array( $rumble_hover, array( 'border', 'pull', 'slide', 'fade' ) ) ) {
				rumble_show_post_meta(
					apply_filters(
						'rumble_filter_post_meta_args', array(
							'components' => $rumble_components,
							'seo'        => false,
						), 'excerpt', 1
					)
				);
			}

			do_action( 'rumble_action_before_post_title' );

			// Post title
			if ( empty( $rumble_template_args['no_links'] ) ) {
				the_title( sprintf( '<h2 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
			} else {
				the_title( '<h2 class="post_title entry-title">', '</h2>' );
			}
			?>
		</div><!-- .post_header -->
		<?php
	} else{
        // Post meta

        if ( ! empty( $rumble_components ) && ($rumble_post_format !== 'quote') && ! in_array( $rumble_hover, array( 'border', 'pull', 'slide', 'fade' ) ) ) {
            rumble_show_post_meta(
                apply_filters(
                    'rumble_filter_post_meta_args', array(
                        'components' => $rumble_components,
                        'seo'        => false,
                    ), 'excerpt', 1
                )
            );
        }
	}

	// Post content
	if ( empty( $rumble_template_args['hide_excerpt'] ) && rumble_get_theme_option( 'excerpt_length' ) > 0 ) {
		?>
		<div class="post_content entry-content">
			<?php
			if ( rumble_get_theme_option( 'blog_content' ) == 'fullpost' ) {
				// Post content area
				?>
				<div class="post_content_inner">
					<?php
					do_action( 'rumble_action_before_full_post_content' );
					the_content( '' );
					do_action( 'rumble_action_after_full_post_content' );
					?>
				</div>
				<?php
				// Inner pages
				wp_link_pages(
					array(
						'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'rumble' ) . '</span>',
						'after'       => '</div>',
						'link_before' => '<span>',
						'link_after'  => '</span>',
						'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'rumble' ) . ' </span>%',
						'separator'   => '<span class="screen-reader-text">, </span>',
					)
				);
			} else {
				// Post content area
				rumble_show_post_content( $rumble_template_args, '<div class="post_content_inner">', '</div>' );
                      if ( 'quote' == $rumble_post_format ) {
                        if ( ! empty( $rumble_components ) && ! in_array( $rumble_hover, array( 'border', 'pull', 'slide', 'fade' ) ) ) {
                        rumble_show_post_meta(
                            apply_filters(
                                'rumble_filter_post_meta_args', array(
                                    'components' => $rumble_components,
                                    'seo'        => false,
                                ), 'excerpt', 1
                            )
                        );
                    }
				}


			}
			?>
		</div><!-- .entry-content -->
		<?php
	}
	?>
</article>
<?php

if ( is_array( $rumble_template_args ) ) {
	if ( ! empty( $rumble_template_args['slider'] ) || $rumble_columns > 1 ) {
		?>
		</div>
		<?php
	}
}
