<?php
/**
 * The default template to display the content of the single post, page or attachment
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage RUMBLE
 * @since RUMBLE 1.0
 */

$rumble_seo = rumble_is_on( rumble_get_theme_option( 'seo_snippets' ) );
?>
<article id="post-<?php the_ID(); ?>" 
	<?php
	post_class('post_item_single post_type_' . esc_attr( get_post_type() ) 
		. ' post_format_' . esc_attr( str_replace( 'post-format-', '', get_post_format() ) )
	);
	if ( $rumble_seo ) {
		?>
		itemscope="itemscope" 
		itemprop="articleBody" 
		itemtype="//schema.org/<?php echo esc_attr( rumble_get_markup_schema() ); ?>"
		itemid="<?php echo esc_url( get_the_permalink() ); ?>"
		content="<?php the_title_attribute(); ?>"
		<?php
	}
	?>
>
<?php

	do_action( 'rumble_action_before_post_data' );

	// Structured data snippets
	if ( $rumble_seo ) {
		get_template_part( apply_filters( 'rumble_filter_get_template_part', 'templates/seo' ) );
	}

	if ( is_singular( 'post' ) || is_singular( 'attachment' ) ) {
		$rumble_post_thumbnail_type  = rumble_get_theme_option( 'post_thumbnail_type' );
		$rumble_post_header_position = rumble_get_theme_option( 'post_header_position' );
		$rumble_post_header_align    = rumble_get_theme_option( 'post_header_align' );

		if ( 'default' === $rumble_post_thumbnail_type && 'default' !== $rumble_post_header_position ) {
			?>
			<div class="header_content_wrap header_align_<?php echo esc_attr( $rumble_post_header_align ); ?>">
				<?php
				// Post title and meta
				if ( 'above' === $rumble_post_header_position ) {
					rumble_show_post_title_and_meta();
				}

				// Featured image
				rumble_show_post_featured_image();

				// Post title and meta
				if ( 'above' !== $rumble_post_header_position ) {
					rumble_show_post_title_and_meta();
				}
				?>
			</div>
			<?php
		} elseif ( 'default' !== $rumble_post_thumbnail_type && 'default' === $rumble_post_header_position ) {
			// Post title and meta
			rumble_show_post_title_and_meta();

		}
	}

	do_action( 'rumble_action_before_post_content' );

    // Featured image
    $post_type = get_post_type();
    if( $post_type == 'mp-event') {
        if (!rumble_sc_layouts_showed('featured')) {
            rumble_show_post_featured_image();
        }
    }

// Post content

	?>
	<div class="post_content post_content_single entry-content" itemprop="mainEntityOfPage">
		<?php
		the_content();

		do_action( 'rumble_action_before_post_pagination' );

		wp_link_pages(
			array(
				'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'rumble' ) . '</span>',
				'after'       => '</div>',
				'link_before' => '<span>',
				'link_after'  => '</span>',
				'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'rumble' ) . ' </span>%',
				'separator'   => '<span class="screen-reader-text">, </span>',
			)
		);

		// Taxonomies and share
		if ( is_single() && ! is_attachment() ) {

			do_action( 'rumble_action_before_post_meta' );
			?>

			<div class="post_meta post_meta_single">
				<?php

				// Post taxonomies
				the_tags( '<div class="post_meta_item post_tags"><span class="post_meta_label">' . esc_html__( 'Tags:', 'rumble' ) . '</span> ', ', ', '</div>' );

				// Share
				if ( rumble_is_on( rumble_get_theme_option( 'show_share_links' ) ) ) {
					rumble_show_share_links(
						array(
							'type'    => 'block',
							'caption' => 'Share:',
							'before'  => '<div class="post_meta_item post_share">',
							'after'   => '</div>',
						)
					);
				}
				?>
			</div>
			<?php

			do_action( 'rumble_action_after_post_meta' );
		}
		?>
	</div><!-- .entry-content -->


	<?php
	do_action( 'rumble_action_after_post_content' );

	do_action( 'rumble_action_after_post_data' );
	?>
</article>
