<?php
/**
 * The template for homepage posts with custom style
 *
 * @package WordPress
 * @subpackage RUMBLE
 * @since RUMBLE 1.0.50
 */

rumble_storage_set( 'blog_archive', true );

get_header();

if ( have_posts() ) {

	$rumble_blog_style = rumble_get_theme_option( 'blog_style' );
	$rumble_parts      = explode( '_', $rumble_blog_style );
	$rumble_columns    = ! empty( $rumble_parts[1] ) ? max( 1, min( 6, (int) $rumble_parts[1] ) ) : 1;
	$rumble_blog_id    = rumble_get_custom_blog_id( $rumble_blog_style );
	$rumble_blog_meta  = rumble_get_custom_layout_meta( $rumble_blog_id );
	if ( ! empty( $rumble_blog_meta['margin'] ) ) {
		rumble_add_inline_css( sprintf( '.page_content_wrap{padding-top:%s}', esc_attr( rumble_prepare_css_value( $rumble_blog_meta['margin'] ) ) ) );
	}
	$rumble_custom_style = ! empty( $rumble_blog_meta['scripts_required'] ) ? $rumble_blog_meta['scripts_required'] : 'none';

	rumble_blog_archive_start();

	$rumble_classes    = 'posts_container blog_custom_wrap'
							. ( ! rumble_is_off( $rumble_custom_style )
								? sprintf( ' %s_wrap', $rumble_custom_style )
								: ( $rumble_columns > 1
									? ' columns_wrap columns_padding_bottom' 
									: ''
									)
								);
	$rumble_stickies   = is_home() ? get_option( 'sticky_posts' ) : false;
	$rumble_sticky_out = rumble_get_theme_option( 'sticky_style' ) == 'columns'
							&& is_array( $rumble_stickies ) && count( $rumble_stickies ) > 0 && get_query_var( 'paged' ) < 1;
	if ( $rumble_sticky_out ) {
		?>
		<div class="sticky_wrap columns_wrap">
		<?php
	}
	if ( ! $rumble_sticky_out ) {
		if ( rumble_get_theme_option( 'first_post_large' ) && ! is_paged() && ! in_array( rumble_get_theme_option( 'body_style' ), array( 'fullwide', 'fullscreen' ) ) ) {
			the_post();
			get_template_part( apply_filters( 'rumble_filter_get_template_part', 'content', 'excerpt' ), 'excerpt' );
		}
		?>
		<div class="<?php echo esc_attr( $rumble_classes ); ?>">
		<?php
	}
	while ( have_posts() ) {
		the_post();
		if ( $rumble_sticky_out && ! is_sticky() ) {
			$rumble_sticky_out = false;
			?>
			</div><div class="<?php echo esc_attr( $rumble_classes ); ?>">
			<?php
		}
		$rumble_part = $rumble_sticky_out && is_sticky() ? 'sticky' : 'custom';
		get_template_part( apply_filters( 'rumble_filter_get_template_part', 'content', $rumble_part ), $rumble_part );
	}
	?>
	</div>
	<?php

	rumble_show_pagination();

	rumble_blog_archive_end();

} else {

	if ( is_search() ) {
		get_template_part( apply_filters( 'rumble_filter_get_template_part', 'content', 'none-search' ), 'none-search' );
	} else {
		get_template_part( apply_filters( 'rumble_filter_get_template_part', 'content', 'none-archive' ), 'none-archive' );
	}
}

get_footer();
