<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage RUMBLE
 * @since RUMBLE 1.0
 */

rumble_storage_set( 'blog_archive', true );

get_header();

if ( have_posts() ) {

	rumble_blog_archive_start();

	$rumble_stickies   = is_home() ? get_option( 'sticky_posts' ) : false;
	$rumble_sticky_out = rumble_get_theme_option( 'sticky_style' ) == 'columns'
							&& is_array( $rumble_stickies ) && count( $rumble_stickies ) > 0 && get_query_var( 'paged' ) < 1;

	// Show filters
	$rumble_cat          = rumble_get_theme_option( 'parent_cat' );
	$rumble_post_type    = rumble_get_theme_option( 'post_type' );
	$rumble_taxonomy     = rumble_get_post_type_taxonomy( $rumble_post_type );
	$rumble_show_filters = rumble_get_theme_option( 'show_filters' );
	$rumble_tabs         = array();
	if ( ! rumble_is_off( $rumble_show_filters ) ) {
		$rumble_args           = array(
			'type'         => $rumble_post_type,
			'child_of'     => $rumble_cat,
			'orderby'      => 'name',
			'order'        => 'ASC',
			'hide_empty'   => 1,
			'hierarchical' => 0,
			'taxonomy'     => $rumble_taxonomy,
			'pad_counts'   => false,
		);
		$rumble_portfolio_list = get_terms( $rumble_args );
		if ( is_array( $rumble_portfolio_list ) && count( $rumble_portfolio_list ) > 0 ) {
			$rumble_tabs[ $rumble_cat ] = esc_html__( 'All', 'rumble' );
			foreach ( $rumble_portfolio_list as $rumble_term ) {
				if ( isset( $rumble_term->term_id ) ) {
					$rumble_tabs[ $rumble_term->term_id ] = $rumble_term->name;
				}
			}
		}
	}
	if ( count( $rumble_tabs ) > 0 ) {
		$rumble_portfolio_filters_ajax   = true;
		$rumble_portfolio_filters_active = $rumble_cat;
		$rumble_portfolio_filters_id     = 'portfolio_filters';
		?>
		<div class="portfolio_filters rumble_tabs rumble_tabs_ajax">
			<ul class="portfolio_titles rumble_tabs_titles">
				<?php
				foreach ( $rumble_tabs as $rumble_id => $rumble_title ) {
					?>
					<li><a href="<?php echo esc_url( rumble_get_hash_link( sprintf( '#%s_%s_content', $rumble_portfolio_filters_id, $rumble_id ) ) ); ?>" data-tab="<?php echo esc_attr( $rumble_id ); ?>"><?php echo esc_html( $rumble_title ); ?></a></li>
					<?php
				}
				?>
			</ul>
			<?php
			$rumble_ppp = rumble_get_theme_option( 'posts_per_page' );
			if ( rumble_is_inherit( $rumble_ppp ) ) {
				$rumble_ppp = '';
			}
			foreach ( $rumble_tabs as $rumble_id => $rumble_title ) {
				$rumble_portfolio_need_content = $rumble_id == $rumble_portfolio_filters_active || ! $rumble_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr( sprintf( '%s_%s_content', $rumble_portfolio_filters_id, $rumble_id ) ); ?>"
					class="portfolio_content rumble_tabs_content"
					data-blog-template="<?php echo esc_attr( rumble_storage_get( 'blog_template' ) ); ?>"
					data-blog-style="<?php echo esc_attr( rumble_get_theme_option( 'blog_style' ) ); ?>"
					data-posts-per-page="<?php echo esc_attr( $rumble_ppp ); ?>"
					data-post-type="<?php echo esc_attr( $rumble_post_type ); ?>"
					data-taxonomy="<?php echo esc_attr( $rumble_taxonomy ); ?>"
					data-cat="<?php echo esc_attr( $rumble_id ); ?>"
					data-parent-cat="<?php echo esc_attr( $rumble_cat ); ?>"
					data-need-content="<?php echo ( false === $rumble_portfolio_need_content ? 'true' : 'false' ); ?>"
				>
					<?php
					if ( $rumble_portfolio_need_content ) {
						rumble_show_portfolio_posts(
							array(
								'cat'        => $rumble_id,
								'parent_cat' => $rumble_cat,
								'taxonomy'   => $rumble_taxonomy,
								'post_type'  => $rumble_post_type,
								'page'       => 1,
								'sticky'     => $rumble_sticky_out,
							)
						);
					}
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		rumble_show_portfolio_posts(
			array(
				'cat'        => $rumble_cat,
				'parent_cat' => $rumble_cat,
				'taxonomy'   => $rumble_taxonomy,
				'post_type'  => $rumble_post_type,
				'page'       => 1,
				'sticky'     => $rumble_sticky_out,
			)
		);
	}

	rumble_blog_archive_end();

} else {

	if ( is_search() ) {
		get_template_part( apply_filters( 'rumble_filter_get_template_part', 'content', 'none-search' ), 'none-search' );
	} else {
		get_template_part( apply_filters( 'rumble_filter_get_template_part', 'content', 'none-archive' ), 'none-archive' );
	}
}

get_footer();
