<?php
/* ThemeREX Addons support functions
------------------------------------------------------------------------------- */

// Add theme-specific functions
require_once RUMBLE_THEME_DIR . 'theme-specific/rumble_addons.setup.php';

// Theme init priorities:
// 1 - register filters, that add/remove lists items for the Theme Options
if ( ! function_exists( 'rumble_addons_support_theme_setup1' ) ) {
	add_action( 'after_setup_theme', 'rumble_addons_support_theme_setup1', 1 );
	function rumble_addons_support_theme_setup1() {
		if ( rumble_exists_rumble_addons() ) {
			add_filter( 'rumble_filter_list_posts_types', 'rumble_addons_support_list_post_types' );
		}
	}
}

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if ( ! function_exists( 'rumble_addons_support_theme_setup9' ) ) {
	add_action( 'after_setup_theme', 'rumble_addons_support_theme_setup9', 9 );
	function rumble_addons_support_theme_setup9() {

		if ( rumble_exists_rumble_addons() ) {
			add_action( 'wp_enqueue_scripts', 'rumble_addons_support_frontend_scripts', 1100 );
			add_action( 'wp_enqueue_scripts', 'rumble_addons_support_responsive_scripts', 2000 );
			add_filter( 'rumble_filter_merge_styles', 'rumble_addons_support_merge_styles' );
			add_filter( 'rumble_filter_merge_styles_responsive', 'rumble_addons_merge_styles_responsive' );
			add_filter( 'rumble_filter_merge_scripts', 'rumble_addons_support_merge_scripts' );
			add_filter( 'rumble_filter_post_type_taxonomy', 'rumble_addons_support_post_type_taxonomy', 10, 2 );
			if ( is_admin() ) {
				add_filter( 'rumble_filter_allow_override_options', 'rumble_addons_support_allow_override_options', 10, 2 );
			} else {
				add_filter( 'rumble_filter_detect_blog_mode', 'rumble_addons_support_detect_blog_mode' );
			}
		}

		if ( is_admin() ) {
			add_filter( 'rumble_filter_tgmpa_required_plugins', 'rumble_addons_support_tgmpa_required_plugins' );
		}
	}
}

// Filter to add in the required plugins list
if ( ! function_exists( 'rumble_addons_support_tgmpa_required_plugins' ) ) {
	
	function rumble_addons_support_tgmpa_required_plugins( $list = array() ) {
		if ( rumble_storage_isset( 'required_plugins', 'rumble-addons' ) && rumble_storage_get_array( 'required_plugins', 'rumble-addons', 'install' ) !== false ) {
			$path = rumble_get_plugin_source_path( 'plugins/rumble-addons/rumble-addons.zip' );
			if ( ! empty( $path ) || rumble_get_theme_setting( 'tgmpa_upload' ) ) {
				$list[] = array(
					'name'     => rumble_storage_get_array( 'required_plugins', 'rumble-addons', 'title' ),
					'slug'     => 'rumble-addons',
					'version'  => '1.0.0',
					'source'   => ! empty( $path ) ? $path : 'upload://rumble-addons.zip',
					'required' => true,
				);
			}
		}
		return $list;
	}
}


/* Add options in the Theme Options Customizer
------------------------------------------------------------------------------- */

// Return plugin's specific options for CPT
if ( ! function_exists( 'rumble_addons_support_get_list_cpt_options' ) ) {
	function rumble_addons_support_get_list_cpt_options( $cpt ) {
		$options = array();
		if ( 'portfolio' == $cpt ) {
			$options = rumble_addons_cpt_example_get_list_options();
		}
		// Remove parameter 'hidden'
		foreach ( $options as $k => $v ) {
			if ( ! empty( $v['hidden'] ) ) {
				unset( $options[ $k ]['hidden'] );
			}
		}
		return $options;
	}
}

// Theme init priorities:
// 3 - add/remove Theme Options elements
if ( ! function_exists( 'rumble_addons_support_setup3' ) ) {
	add_action( 'after_setup_theme', 'rumble_addons_support_setup3', 3 );
	function rumble_addons_support_setup3() {

		// Section 'CPT_Name' - settings to show 'CPT_Name' blog archive and single posts
		if ( rumble_exists_example() ) {
			rumble_storage_merge_array(
				'options', '', array_merge(
					array(
						'example' => array(
							'title' => esc_html__( 'CPT_Name', 'rumble' ),
							'desc'  => wp_kses_data( __( 'Select parameters to display the CPT_Name pages', 'rumble' ) )
										. '<br>'
										. wp_kses_data( __( 'Attention! Option "Style" apply only after you save the options!', 'rumble' ) ),
							'type'  => 'section',
						),
					),
					rumble_addons_support_get_list_cpt_options( 'example' ),
					rumble_options_get_list_cpt_options( 'example' ),
					array(
						'single_info_example'        => array(
							'title' => esc_html__( 'Single CPT_Name item', 'rumble' ),
							'desc'  => '',
							'type'  => 'info',
						),
						'show_related_posts_example' => array(
							'title' => esc_html__( 'Show related posts', 'rumble' ),
							'desc'  => wp_kses_data( __( "Show section 'Related CPT_Name items' on the single CPT_Name page", 'rumble' ) ),
							'std'   => 1,
							'type'  => 'checkbox',
						),
						'related_posts_example'      => array(
							'title'      => esc_html__( 'Related CPT_Name items', 'rumble' ),
							'desc'       => wp_kses_data( __( 'How many related CPT_Name items should be displayed on the single CPT_Name page?', 'rumble' ) ),
							'dependency' => array(
								'show_related_posts_example' => array( 1 ),
							),
							'std'        => 3,
							'options'    => rumble_get_list_range( 1, 9 ),
							'type'       => 'select',
						),
						'related_columns_example'    => array(
							'title'      => esc_html__( 'Related columns', 'rumble' ),
							'desc'       => wp_kses_data( __( 'How many columns should be used to output related CPT_Name on the single CPT_Name page?', 'rumble' ) ),
							'dependency' => array(
								'show_related_posts_example' => array( 1 ),
							),
							'std'        => 3,
							'options'    => rumble_get_list_range( 1, 4 ),
							'type'       => 'select',
						),
					)
				)
			);
		}
	}
}



/* Plugin's support utilities
------------------------------------------------------------------------------- */

// Check if plugin installed and activated
if ( ! function_exists( 'rumble_exists_rumble_addons' ) ) {
	function rumble_exists_rumble_addons() {
		return function_exists( 'rumble_addons_init' );
	}
}

// Return true if CPT_Name is supported
if ( ! function_exists( 'rumble_exists_example' ) ) {
	function rumble_exists_example() {
		return defined( 'RUMBLE_ADDONS_CPT_EXAMPLE_PT' );
	}
}

// Return true if it's CPT_Name page
if ( ! function_exists( 'rumble_is_example_page' ) ) {
	function rumble_is_example_page() {
		return function_exists( 'trx_addons_is_example_page' ) && trx_addons_is_example_page();
	}
}

// Detect current blog mode
if ( ! function_exists( 'rumble_addons_support_detect_blog_mode' ) ) {
	
	function rumble_addons_support_detect_blog_mode( $mode = '' ) {
		if ( rumble_is_portfolio_page() ) {
			$mode = 'portfolio';
		}
		return $mode;
	}
}

// Add CPT_Name to the supported posts list
if ( ! function_exists( 'rumble_addons_support_list_post_types' ) ) {
	
	function rumble_addons_support_list_post_types( $list = array() ) {
		if ( defined( 'RUMBLE_ADDONS_CPT_EXAMPLE_PT' ) ) {
			$list[ RUMBLE_ADDONS_CPT_EXAMPLE_PT ] = esc_html__( 'CPT_Name', 'rumble' );
		}
		return $list;
	}
}

// Return taxonomy for current post type
if ( ! function_exists( 'rumble_addons_support_post_type_taxonomy' ) ) {
	
	function rumble_addons_support_post_type_taxonomy( $tax = '', $post_type = '' ) {
		if ( defined( 'RUMBLE_ADDONS_CPT_EXAMPLE_PT' ) && RUMBLE_ADDONS_CPT_EXAMPLE_PT == $post_type ) {
			$tax = RUMBLE_ADDONS_CPT_EXAMPLE_TAXONOMY;
		}
		return $tax;
	}
}

// Show categories of the CPT_Name
if ( ! function_exists( 'rumble_addons_support_get_post_categories' ) ) {
	
	function rumble_addons_support_get_post_categories( $cats = '' ) {

		if ( defined( 'RUMBLE_ADDONS_CPT_EXAMPLE_PT' ) ) {
			if ( get_post_type() == RUMBLE_ADDONS_CPT_EXAMPLE_PT ) {
				$cats = rumble_get_post_terms( ', ', get_the_ID(), RUMBLE_ADDONS_CPT_EXAMPLE_TAXONOMY );
			}
		}
		return $cats;
	}
}


// Check if override options is allowed
if ( ! function_exists( 'rumble_addons_support_allow_override_options' ) ) {
	
	function rumble_addons_support_allow_override_options( $allow, $post_type ) {
		return $allow || ( defined( 'RUMBLE_ADDONS_CPT_EXAMPLE_PT' ) && RUMBLE_ADDONS_CPT_EXAMPLE_PT == $post_type );
	}
}

// Set related posts and columns for the plugin's output
if ( ! function_exists( 'rumble_addons_support_args_related' ) ) {
	
	function rumble_addons_support_args_related( $args ) {
		if ( ! empty( $args['template_args_name'] )
			&& in_array(
				$args['template_args_name'],
				array( 'trx_addons_args_sc_example' )
			) ) {
			$args['posts_per_page'] = (int) rumble_get_theme_option( 'show_related_posts' )
												? rumble_get_theme_option( 'related_posts' )
												: 0;
			$args['columns']        = rumble_get_theme_option( 'related_columns' );
		}
		return $args;
	}
}


// Enqueue custom styles
if ( ! function_exists( 'rumble_addons_support_frontend_scripts' ) ) {
	
	function rumble_addons_support_frontend_scripts() {
		if ( rumble_exists_rumble_addons() ) {
			if ( rumble_is_on( rumble_get_theme_option( 'debug_mode' ) ) ) {
				$rumble_url = rumble_get_file_url( 'plugins/rumble-addons/rumble-addons.css' );
				if ( '' != $rumble_url ) {
					wp_enqueue_style( 'rumble-addons',  $rumble_url, array(), null );
				}
				$rumble_url = rumble_get_file_url( 'plugins/rumble-addons/rumble-addons.js' );
				if ( '' != $rumble_url ) {
					wp_enqueue_script( 'rumble-addons', $rumble_url, array( 'jquery' ), null, true );
				}
			}
		}
	}
}


// Enqueue responsive styles
if ( ! function_exists( 'rumble_addons_support_responsive_styles' ) ) {
	
	function rumble_addons_support_responsive_styles() {
		if ( rumble_exists_rumble_addons() ) {
			if ( rumble_is_on( rumble_get_theme_option( 'debug_mode' ) ) ) {
				$rumble_url = rumble_get_file_url( 'plugins/rumble-addons/rumble-addons-responsive.css' );
				if ( '' != $rumble_url ) {
					wp_enqueue_style( 'rumble-addons-responsive',  $rumble_url, array(), null );
				}
			}
		}
	}
}

// Merge custom styles
if ( ! function_exists( 'rumble_addons_support_merge_styles' ) ) {
	
	function rumble_addons_support_merge_styles( $list ) {
		$list[] = 'plugins/rumble-addons/rumble-addons.css';
		return $list;
	}
}

// Merge responsive styles
if ( ! function_exists( 'rumble_addons_merge_styles_responsive' ) ) {
	
	function rumble_addons_merge_styles_responsive( $list ) {
		return $list;
	}
}

// Merge custom scripts
if ( ! function_exists( 'rumble_addons_support_merge_scripts' ) ) {
	
	function rumble_addons_support_merge_scripts( $list ) {
		return $list;
	}
}



// Plugin API - theme-specific wrappers for plugin functions
//------------------------------------------------------------------------

// Add plugin-specific colors and fonts to the custom CSS
if ( rumble_exists_rumble_addons() ) {
	require_once RUMBLE_THEME_DIR . 'plugins/rumble-addons/rumble-addons-styles.php';
}
