<?php
/* Booked Appointments support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if ( ! function_exists( 'rumble_booked_theme_setup9' ) ) {
	add_action( 'after_setup_theme', 'rumble_booked_theme_setup9', 9 );
	function rumble_booked_theme_setup9() {
		if ( rumble_exists_booked() ) {
			add_action( 'wp_enqueue_scripts', 'rumble_booked_frontend_scripts', 1100 );
			add_filter( 'rumble_filter_merge_styles', 'rumble_booked_merge_styles' );
		}
		if ( is_admin() ) {
			add_filter( 'rumble_filter_tgmpa_required_plugins', 'rumble_booked_tgmpa_required_plugins' );
			add_filter( 'rumble_filter_theme_plugins', 'rumble_booked_theme_plugins' );
		}
	}
}

// Filter to add in the required plugins list
if ( ! function_exists( 'rumble_booked_tgmpa_required_plugins' ) ) {
	
	function rumble_booked_tgmpa_required_plugins( $list = array() ) {
		if ( rumble_storage_isset( 'required_plugins', 'booked' ) && rumble_storage_get_array( 'required_plugins', 'booked', 'install' ) !== false && rumble_is_theme_activated() ) {
			$path = rumble_get_plugin_source_path( 'plugins/booked/booked.zip' );
			if ( ! empty( $path ) || rumble_get_theme_setting( 'tgmpa_upload' ) ) {
				$list[] = array(
					'name'     => rumble_storage_get_array( 'required_plugins', 'booked', 'title' ),
					'slug'     => 'booked',
                    'version'  => '2.3.5',
					'source'   => ! empty( $path ) ? $path : 'upload://booked.zip',
					'required' => false,
				);
			}
		}
		return $list;
	}
}

// Filter theme-supported plugins list
if ( ! function_exists( 'rumble_booked_theme_plugins' ) ) {
	
	function rumble_booked_theme_plugins( $list = array() ) {
		if ( ! empty( $list['booked']['group'] ) ) {
			foreach ( $list as $k => $v ) {
				if ( substr( $k, 0, 6 ) == 'booked' ) {
					if ( empty( $v['group'] ) ) {
						$list[ $k ]['group'] = $list['booked']['group'];
					}
					if ( ! empty( $list['booked']['logo'] ) ) {
						$list[ $k ]['logo'] = strpos( $list['booked']['logo'], '//' ) !== false
												? $list['booked']['logo']
												: rumble_get_file_url( "plugins/booked/{$list['booked']['logo']}" );
					}
				}
			}
		}
		return $list;
	}
}



// Check if plugin installed and activated
if ( ! function_exists( 'rumble_exists_booked' ) ) {
	function rumble_exists_booked() {
		return class_exists( 'booked_plugin' );
	}
}


// Enqueue styles for frontend
if ( ! function_exists( 'rumble_booked_frontend_scripts' ) ) {
	
	function rumble_booked_frontend_scripts() {
		if ( rumble_is_on( rumble_get_theme_option( 'debug_mode' ) ) ) {
			$rumble_url = rumble_get_file_url( 'plugins/booked/booked.css' );
			if ( '' != $rumble_url ) {
				wp_enqueue_style( 'rumble-booked', $rumble_url, array(), null );
			}
		}
	}
}


// Merge custom styles
if ( ! function_exists( 'rumble_booked_merge_styles' ) ) {
	
	function rumble_booked_merge_styles( $list ) {
		$list[] = 'plugins/booked/booked.css';
		return $list;
	}
}


// Add plugin-specific colors and fonts to the custom CSS
if ( rumble_exists_booked() ) {
	require_once RUMBLE_THEME_DIR . 'plugins/booked/booked-styles.php';
}
