<?php
/* MP Timetable support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if ( ! function_exists( 'rumble_mptt_theme_setup9' ) ) {
	add_action( 'after_setup_theme', 'rumble_mptt_theme_setup9', 9 );
	function rumble_mptt_theme_setup9() {
		if ( rumble_exists_mptt() ) {
			add_action( 'wp_enqueue_scripts', 'rumble_mptt_frontend_scripts', 1100 );
			add_action( 'wp_enqueue_scripts', 'rumble_mptt_responsive_styles', 2000 );
			add_filter( 'rumble_filter_merge_styles', 'rumble_mptt_merge_styles' );
			add_filter( 'rumble_filter_merge_styles_responsive', 'rumble_mptt_merge_styles_responsive' );
		}
		if ( is_admin() ) {
			add_filter( 'rumble_filter_tgmpa_required_plugins', 'rumble_mptt_tgmpa_required_plugins' );
		}
	}
}

// Filter to add in the required plugins list
if ( ! function_exists( 'rumble_mptt_tgmpa_required_plugins' ) ) {
	
	function rumble_mptt_tgmpa_required_plugins( $list = array() ) {
		if ( rumble_storage_isset( 'required_plugins', 'mp-timetable' ) && rumble_storage_get_array( 'required_plugins', 'mp-timetable', 'install' ) !== false && rumble_is_theme_activated() ) {
			$path = rumble_get_plugin_source_path( 'plugins/mp-timetable/mp-timetable.zip' );
			if ( ! empty( $path ) || rumble_get_theme_setting( 'tgmpa_upload' ) ) {
				$list[] = array(
					'name'     => rumble_storage_get_array( 'required_plugins', 'mp-timetable', 'title' ),
					'slug'     => 'mp-timetable',
					'source'   => ! empty( $path ) ? $path : 'upload://mp-timetable.zip',
					'required' => false,
				);
			}
		}
		return $list;
	}
}

// Check if plugin is installed and activated
if ( ! function_exists( 'rumble_exists_mp_timetable' ) ) {
	function rumble_exists_mptt() {
		return class_exists( 'Mp_Time_Table' );
	}
}

// Enqueue styles for frontend
if ( ! function_exists( 'rumble_mptt_frontend_scripts' ) ) {
	
	function rumble_mptt_frontend_scripts() {
		if ( rumble_is_on( rumble_get_theme_option( 'debug_mode' ) ) ) {
			$rumble_url = rumble_get_file_url( 'plugins/mp-timetable/mp-timetable.css' );
			if ( '' != $rumble_url ) {
				wp_enqueue_style( 'rumble-mptt', $rumble_url, array(), null );
			}
		}
	}
}

// Enqueue responsive styles for frontend
if ( ! function_exists( 'rumble_mptt_responsive_styles' ) ) {
	
	function rumble_mptt_responsive_styles() {
		if ( rumble_is_on( rumble_get_theme_option( 'debug_mode' ) ) ) {
			$rumble_url = rumble_get_file_url( 'plugins/mp-timetable/mp-timetable-responsive.css' );
			if ( '' != $rumble_url ) {
				wp_enqueue_style( 'rumble-mptt-responsive', $rumble_url, array(), null );
			}
		}
	}
}

// Merge custom styles
if ( ! function_exists( 'rumble_mptt_merge_styles' ) ) {
	
	function rumble_mptt_merge_styles( $list ) {
		$list[] = 'plugins/mp-timetable/mp-timetable.css';
		return $list;
	}
}


// Merge responsive styles
if ( ! function_exists( 'rumble_mptt_merge_styles_responsive' ) ) {
	
	function rumble_mptt_merge_styles_responsive( $list ) {
		$list[] = 'plugins/mp-timetable/mp-timetable-responsive.css';
		return $list;
	}
}


// Add plugin-specific colors and fonts to the custom CSS
if ( rumble_exists_mptt() ) {
	require_once RUMBLE_THEME_DIR . 'plugins/mp-timetable/mp-timetable-styles.php'; }

