<?php
/* Revolution Slider support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if ( ! function_exists( 'rumble_revslider_theme_setup9' ) ) {
	add_action( 'after_setup_theme', 'rumble_revslider_theme_setup9', 9 );
	function rumble_revslider_theme_setup9() {
		if ( is_admin() ) {
			add_filter( 'rumble_filter_tgmpa_required_plugins', 'rumble_revslider_tgmpa_required_plugins' );
		}
	}
}

// Filter to add in the required plugins list
if ( ! function_exists( 'rumble_revslider_tgmpa_required_plugins' ) ) {
	
	function rumble_revslider_tgmpa_required_plugins( $list = array() ) {
		if ( rumble_storage_isset( 'required_plugins', 'revslider' ) && rumble_storage_get_array( 'required_plugins', 'revslider', 'install' ) !== false && rumble_is_theme_activated() ) {
			$path = rumble_get_plugin_source_path( 'plugins/revslider/revslider.zip' );
			if ( ! empty( $path ) || rumble_get_theme_setting( 'tgmpa_upload' ) ) {
				$list[] = array(
					'name'     => rumble_storage_get_array( 'required_plugins', 'revslider', 'title' ),
					'slug'     => 'revslider',
                    'version'  => '6.5.25',
					'source'   => ! empty( $path ) ? $path : 'upload://revslider.zip',
					'required' => false,
				);
			}
		}
		return $list;
	}
}

// Check if RevSlider installed and activated
if ( ! function_exists( 'rumble_exists_revslider' ) ) {
	function rumble_exists_revslider() {
		return function_exists( 'rev_slider_shortcode' );
	}
}

// Allow loading RevSlider scripts and styles
// if it present in the content of the current page
if (!function_exists('rumble_revslider_check_revslider_in_content')) {
	add_filter( 'revslider_include_libraries', 'rumble_revslider_check_revslider_in_content' );
	function rumble_revslider_check_revslider_in_content( $load ) {
		if ( ! $load && function_exists( 'trx_addons_check_revslider_in_content' ) && rumble_is_layouts_available() ) {
			// Check slider in the page header
			if ( apply_filters( 'rumble_filter_check_revslider_in_header', true ) ) {
				$header_type = rumble_get_theme_option( 'header_type' );
				if ( 'custom' == $header_type ) {
					$header_id = rumble_get_custom_header_id();
					if ( $header_id > 0 ) {
						$load = trx_addons_check_revslider_in_content( false, $header_id );
					}
				}
			}
			// Check slider in the page footer
			if ( apply_filters( 'rumble_filter_check_revslider_in_footer', false ) ) {
				$footer_type = rumble_get_theme_option( 'footer_type' );
				if ( 'custom' == $footer_type ) {
					$footer_id = rumble_get_custom_footer_id();
					if ( $footer_id > 0 ) {
						$load = trx_addons_check_revslider_in_content( false, $footer_id );
					}
				}
			}
		}
		return $load;
	}
}