<?php
/**
 * The template to display single post
 *
 * @package WordPress
 * @subpackage RUMBLE
 * @since RUMBLE 1.0
 */

get_header();

while ( have_posts() ) {
	the_post();

	// Prepare theme-specific vars:

	// Position of the related posts
	$rumble_related_position = rumble_get_theme_option( 'related_position' );

	// Type of the prev/next posts navigation
	$rumble_posts_navigation = rumble_get_theme_option( 'posts_navigation' );
	if ( 'scroll' == $rumble_posts_navigation ) {
		$rumble_prev_post = get_previous_post( true );         // Get post from same category
		if ( ! $rumble_prev_post ) {
			$rumble_prev_post = get_previous_post( false );    // Get post from any category
			if ( ! $rumble_prev_post ) {
				$rumble_posts_navigation = 'links';
			}
		}
		// Override some theme options to display featured image, title and post meta in the dynamic loaded posts
		if ( $rumble_prev_post && rumble_get_value_gp( 'action' ) == 'prev_post_loading' ) {
			rumble_storage_set_array( 'options_meta', 'post_thumbnail_type', 'default' );
			if ( rumble_get_theme_option( 'post_header_position' ) != 'below' ) {
				rumble_storage_set_array( 'options_meta', 'post_header_position', 'above' );
			}
			rumble_sc_layouts_showed( 'featured', false );
			rumble_sc_layouts_showed( 'title', false );
			rumble_sc_layouts_showed( 'postmeta', false );
		}
	}

	// If related posts should be inside the content
	if ( strpos( $rumble_related_position, 'inside' ) === 0 ) {
		ob_start();
	}

	// Display post's content
	get_template_part( apply_filters( 'rumble_filter_get_template_part', 'content', get_post_format() ), get_post_format() );

	// If related posts should be inside the content
	if ( strpos( $rumble_related_position, 'inside' ) === 0 ) {
		$rumble_content = ob_get_contents();
		ob_end_clean();

		ob_start();
		do_action( 'rumble_action_related_posts' );
		$rumble_related_content = ob_get_contents();
		ob_end_clean();

		$rumble_related_position_inside = max( 0, min( 9, rumble_get_theme_option( 'related_position_inside' ) ) );
		if ( 0 == $rumble_related_position_inside ) {
			$rumble_related_position_inside = mt_rand( 1, 9 );
		}
		
		$rumble_p_number = 0;
		$rumble_related_inserted = false;
		for ( $i = 0; $i < strlen( $rumble_content ) - 3; $i++ ) {
			if ( $rumble_content[ $i ] == '<' && $rumble_content[ $i + 1 ] == 'p' && in_array( $rumble_content[ $i + 2 ], array( '>', ' ' ) ) ) {
				$rumble_p_number++;
				if ( $rumble_related_position_inside == $rumble_p_number ) {
					$rumble_related_inserted = true;
					$rumble_content = ( $i > 0 ? substr( $rumble_content, 0, $i ) : '' )
										. $rumble_related_content
										. substr( $rumble_content, $i );
				}
			}
		}
		if ( ! $rumble_related_inserted ) {
			$rumble_content .= $rumble_related_content;
		}

		rumble_show_layout( $rumble_content );
	}

	// Author bio
	if ( rumble_get_theme_option( 'show_author_info' ) == 1
		&& ! is_attachment()
		&& get_the_author_meta( 'description' )
		&& ( 'scroll' != $rumble_posts_navigation || rumble_get_theme_option( 'posts_navigation_scroll_hide_author' ) == 0 )
	) {
		do_action( 'rumble_action_before_post_author' );
		get_template_part( apply_filters( 'rumble_filter_get_template_part', 'templates/author-bio' ) );
		do_action( 'rumble_action_after_post_author' );
	}

	// Previous/next post navigation.
	if ( 'links' == $rumble_posts_navigation ) {
		do_action( 'rumble_action_before_post_navigation' );
		?>
		<div class="nav-links-single<?php
			if ( ! rumble_is_off( rumble_get_theme_option( 'posts_navigation_fixed' ) ) ) {
				echo ' nav-links-fixed fixed';
			}
		?>">
			<?php
			the_post_navigation(
				array(
					'next_text' => '<span class="nav-arrow"></span>'
						. '<span class="screen-reader-text">' . esc_html__( 'Next post:', 'rumble' ) . '</span> '
						. '<h6 class="post-title">%title</h6>'
						. '<span class="post_date">%date</span>',
					'prev_text' => '<span class="nav-arrow"></span>'
						. '<span class="screen-reader-text">' . esc_html__( 'Previous post:', 'rumble' ) . '</span> '
						. '<h6 class="post-title">%title</h6>'
						. '<span class="post_date">%date</span>',
				)
			);
			?>
		</div>
		<?php
		do_action( 'rumble_action_after_post_navigation' );
	}

	// Related posts
	if ( 'below_content' == $rumble_related_position && ( 'scroll' != $rumble_posts_navigation || rumble_get_theme_option( 'posts_navigation_scroll_hide_related' ) == 0 ) ) {
		do_action( 'rumble_action_related_posts' );
	}

	// If comments are open or we have at least one comment, load up the comment template.
	if ( ( comments_open() || get_comments_number() ) && ( 'scroll' != $rumble_posts_navigation || rumble_get_theme_option( 'posts_navigation_scroll_hide_comments' ) == 0 ) ) {
		do_action( 'rumble_action_before_comments' );
		comments_template();
		do_action( 'rumble_action_after_comments' );
	}

	if ( 'scroll' == $rumble_posts_navigation ) {
		?>
		<div class="nav-links-single-scroll"
			data-post-id="<?php echo esc_attr( get_the_ID( $rumble_prev_post ) ); ?>"
			data-post-link="<?php echo esc_attr( get_permalink( $rumble_prev_post ) ); ?>"
			data-post-title="<?php the_title_attribute( $rumble_prev_post ); ?>">
		</div>
		<?php
	}
}

get_footer();
