<?php
/**
 * Setup theme-specific fonts and colors
 *
 * @package WordPress
 * @subpackage RUMBLE
 * @since RUMBLE 1.0.22
 */

// If this theme is a free version of premium theme
if ( ! defined( 'RUMBLE_THEME_FREE' ) ) {
	define( 'RUMBLE_THEME_FREE', false );
}
if ( ! defined( 'RUMBLE_THEME_FREE_WP' ) ) {
	define( 'RUMBLE_THEME_FREE_WP', false );
}

// If this theme uses multiple skins
if ( ! defined( 'RUMBLE_ALLOW_SKINS' ) ) {
	define( 'RUMBLE_ALLOW_SKINS', false );
}
if ( ! defined( 'RUMBLE_DEFAULT_SKIN' ) ) {
	define( 'RUMBLE_DEFAULT_SKIN', 'default' );
}



// Theme storage
// Attention! Must be in the global namespace to compatibility with WP CLI
//-------------------------------------------------------------------------
$GLOBALS['RUMBLE_STORAGE'] = array(

	// Key validator: market[env|loc]-vendor[axiom|ancora|themerex]
	'theme_pro_key'      => 'env-ancora',

	// Generate Personal token from Envato to automatic upgrade theme
	'upgrade_token_url'  => 'https://build.envato.com/create-token/?default=t&purchase:download=t&purchase:list=t',

	// Theme-specific URLs (will be escaped in place of the output)
	'theme_demo_url'     => '//rumble.ancorathemes.com/',

	'theme_doc_url'      => '//rumble.ancorathemes.com/doc',
	
	'theme_rate_url'     => 'https://themeforest.net/download',

	'theme_custom_url' => '//themerex.net/offers/?utm_source=offers&utm_medium=click&utm_campaign=themedash',

	'theme_download_url' => 'https://themeforest.net/item/rumble-boxing-mixed-martial-arts-wordpress-theme/23632315?s_rank=9',        // Ancora

	'theme_support_url'  => 'https://themerex.net/support/',                    // Ancora

	'theme_video_url'    => 'https://www.youtube.com/channel/UCdIjRh7-lPVHqTTKpaf8PLA',  // Ancora

	'theme_privacy_url'  => 'http://ancorathemes.com/privacy-policy/',                   // Ancora

	// Comma separated slugs of theme-specific categories (for get relevant news in the dashboard widget)
	// (i.e. 'children,kindergarten')
	'theme_categories'   => '',

	// Responsive resolutions
	// Parameters to create css media query: min, max
	'responsive'         => array(
		// By size
		'xxl'        => array( 'max' => 1679 ),
		'xl'         => array( 'max' => 1439 ),
		'lg'         => array( 'max' => 1279 ),
		'md_over'    => array( 'min' => 1024 ),
		'md'         => array( 'max' => 1023 ),
		'sm'         => array( 'max' => 767 ),
		'sm_wp'      => array( 'max' => 600 ),
		'xs'         => array( 'max' => 479 ),
		// By device
		'wide'       => array(
			'min' => 2160
		),
		'desktop'    => array(
			'min' => 1680,
			'max' => 2159,
		),
		'notebook'   => array(
			'min' => 1280,
			'max' => 1679,
		),
		'tablet'     => array(
			'min' => 768,
			'max' => 1279,
		),
		'not_mobile' => array(
			'min' => 768
		),
		'mobile'     => array(
			'max' => 767
		),
	),
);



// THEME-SUPPORTED PLUGINS
// If plugin not need - remove its settings from next array
//----------------------------------------------------------
$rumble_theme_required_plugins_group = esc_html__( 'Core', 'rumble' );
$rumble_theme_required_plugins = array(
	// Section: "CORE" (required plugins)
	// DON'T COMMENT OR REMOVE NEXT LINES!
	'trx_addons'         => array(
								'title'       => esc_html__( 'ThemeREX Addons', 'rumble' ),
								'description' => esc_html__( "Will allow you to install recommended plugins, demo content, and improve the theme's functionality overall with multiple theme options", 'rumble' ),
								'required'    => true,
								'logo'        => 'logo.png',
								'group'       => $rumble_theme_required_plugins_group,
							),
);

// Section: "PAGE BUILDERS"
$rumble_theme_required_plugins_group = esc_html__( 'Page Builders', 'rumble' );
$rumble_theme_required_plugins['elementor'] = array(
	'title'       => esc_html__( 'Elementor', 'rumble' ),
	'description' => esc_html__( "Is a beautiful PageBuilder, even the free version of which allows you to create great pages using a variety of modules.", 'rumble' ),
	'required'    => false,
	'logo'        => 'logo.png',
	'group'       => $rumble_theme_required_plugins_group,
);
$rumble_theme_required_plugins['gutenberg'] = array(
	'title'       => esc_html__( 'Gutenberg', 'rumble' ),
	'description' => esc_html__( "It's a posts editor coming in place of the classic TinyMCE. Can be installed and used in parallel with Elementor", 'rumble' ),
	'required'    => false,
	'install'     => false,      // Do not offer installation of the plugin in the Theme Dashboard and TGMPA
	'logo'        => 'logo.png',
	'group'       => $rumble_theme_required_plugins_group,
);
if ( ! RUMBLE_THEME_FREE ) {
	$rumble_theme_required_plugins['js_composer']          = array(
		'title'       => esc_html__( 'WPBakery PageBuilder', 'rumble' ),
		'description' => esc_html__( "Popular PageBuilder which allows you to create excellent pages", 'rumble' ),
		'required'    => false,
        'install'     => false,
        'logo'        => 'logo.jpg',
		'group'       => $rumble_theme_required_plugins_group,
	);
	$rumble_theme_required_plugins['vc-extensions-bundle'] = array(
		'title'       => esc_html__( 'WPBakery PageBuilder extensions bundle', 'rumble' ),
		'description' => esc_html__( "Many shortcodes for the WPBakery PageBuilder", 'rumble' ),
		'required'    => false,
		'logo'        => 'logo.png',
		'group'       => $rumble_theme_required_plugins_group,
	);
}

// Section: "E-COMMERCE"
$rumble_theme_required_plugins_group = esc_html__( 'E-Commerce', 'rumble' );
$rumble_theme_required_plugins['woocommerce']              = array(
	'title'       => esc_html__( 'WooCommerce', 'rumble' ),
	'description' => esc_html__( "Connect the store to your website and start selling now", 'rumble' ),
	'required'    => false,
	'logo'        => 'logo.png',
	'group'       => $rumble_theme_required_plugins_group,
);
$rumble_theme_required_plugins['elegro-payment']              = array(
    'title'       => esc_html__( 'Elegro Crypto Payment', 'rumble' ),
    'description' => '',
    'required'    => false,
    'logo'        => 'logo.png',
    'group'       => $rumble_theme_required_plugins_group,
);

// Section: "SOCIALS & COMMUNITIES"
$rumble_theme_required_plugins_group = esc_html__( 'Socials and Communities', 'rumble' );

$rumble_theme_required_plugins['instagram-feed']   = array(
	'title'       => esc_html__( 'Instagram Feed', 'rumble' ),
	'description' => esc_html__( "Displays the latest photos from your profile on Instagram", 'rumble' ),
	'required'    => false,
	'logo'        => 'logo.png',
	'group'       => $rumble_theme_required_plugins_group,
);

$rumble_theme_required_plugins['trx_socials']   = array(
	'title'       => esc_html__( 'TRX Socials', 'rumble' ),
	'description' => esc_html__( "Displays the latest photos from your profile on Instagram", 'rumble' ),
	'required'    => false,
	'logo'        => false,
	'group'       => $rumble_theme_required_plugins_group,
);
$rumble_theme_required_plugins['mailchimp-for-wp'] = array(
	'title'       => esc_html__( 'MailChimp for WP', 'rumble' ),
	'description' => esc_html__( "Allows visitors to subscribe to newsletters", 'rumble' ),
	'required'    => false,
	'logo'        => 'logo.png',
	'group'       => $rumble_theme_required_plugins_group,
);

// Section: "EVENTS & TIMELINES"
$rumble_theme_required_plugins_group = esc_html__( 'Events and Appointments', 'rumble' );
if ( ! RUMBLE_THEME_FREE ) {
	$rumble_theme_required_plugins['booked']                 = array(
		'title'       => esc_html__( 'Booked Appointments', 'rumble' ),
		'description' => '',
		'required'    => false,
		'logo'        => 'logo.png',
		'group'       => $rumble_theme_required_plugins_group,
	);
	$rumble_theme_required_plugins['mp-timetable']           = array(
		'title'       => esc_html__( 'MP Time Table', 'rumble' ),
		'description' => '',
		'required'    => false,
		'logo'        => 'logo.png',
		'group'       => $rumble_theme_required_plugins_group,
	);
	$rumble_theme_required_plugins['the-events-calendar']    = array(
		'title'       => esc_html__( 'The Events Calendar', 'rumble' ),
		'description' => '',
		'required'    => false,
		'logo'        => 'logo.png',
		'group'       => $rumble_theme_required_plugins_group,
	);
}

// Section: "CONTENT"
$rumble_theme_required_plugins_group = esc_html__( 'Content', 'rumble' );
$rumble_theme_required_plugins['contact-form-7'] = array(
	'title'       => esc_html__( 'Contact Form 7', 'rumble' ),
	'description' => esc_html__( "CF7 allows you to create an unlimited number of contact forms", 'rumble' ),
	'required'    => false,
	'logo'        => 'logo.jpg',
	'group'       => $rumble_theme_required_plugins_group,
);
if ( ! RUMBLE_THEME_FREE ) {
	$rumble_theme_required_plugins['essential-grid']             = array(
		'title'       => esc_html__( 'Essential Grid', 'rumble' ),
		'description' => '',
		'required'    => false,
		'logo'        => 'logo.png',
		'group'       => $rumble_theme_required_plugins_group,
	);
	$rumble_theme_required_plugins['revslider']                  = array(
		'title'       => esc_html__( 'Revolution Slider', 'rumble' ),
		'description' => '',
		'required'    => false,
		'logo'        => 'logo.png',
		'group'       => $rumble_theme_required_plugins_group,
	);
}

// Section: "OTHER"
$rumble_theme_required_plugins_group = esc_html__( 'Other', 'rumble' );
$rumble_theme_required_plugins['wp-gdpr-compliance'] = array(
	'title'       => esc_html__( 'Cookie Information', 'rumble' ),
	'description' => esc_html__( "Allow visitors to decide for themselves what personal data they want to store on your site", 'rumble' ),
	'required'    => false,
	'logo'        => 'logo.png',
	'group'       => $rumble_theme_required_plugins_group,
);
$rumble_theme_required_plugins['search-filter'] = array(
    'title'       => esc_html__( 'Search & Filter', 'rumble' ),
    'description' => '',
    'required'    => false,
    'logo'        => 'logo.png',
    'group'       => esc_html__( 'Other', 'rumble' ),
);

$rumble_theme_required_plugins['trx_updater'] = array(
    'title'       => esc_html__( 'ThemeREX Updater', 'rumble' ),
    'description' => '',
    'required'    => false,
    'logo'        => 'logo.png',
    'group'       => esc_html__( 'Other', 'rumble' ),
);

// Add plugins list to the global storage
$GLOBALS['RUMBLE_STORAGE']['required_plugins'] = $rumble_theme_required_plugins;



// THEME-SPECIFIC BLOG LAYOUTS
//----------------------------------------------
$rumble_theme_blog_styles = array(
	'excerpt' => array(
		'title'   => esc_html__( 'Standard', 'rumble' ),
		'archive' => 'index-excerpt',
		'item'    => 'content-excerpt',
		'styles'  => 'excerpt',
	),
	'classic' => array(
		'title'   => esc_html__( 'Classic', 'rumble' ),
		'archive' => 'index-classic',
		'item'    => 'content-classic',
		'columns' => array( 2, 3 ),
		'styles'  => 'classic',
	),
);
if ( ! RUMBLE_THEME_FREE ) {
	$rumble_theme_blog_styles['masonry']   = array(
		'title'   => esc_html__( 'Masonry', 'rumble' ),
		'archive' => 'index-classic',
		'item'    => 'content-classic',
		'columns' => array( 2, 3 ),
		'styles'  => 'masonry',
	);
	$rumble_theme_blog_styles['portfolio'] = array(
		'title'   => esc_html__( 'Portfolio', 'rumble' ),
		'archive' => 'index-portfolio',
		'item'    => 'content-portfolio',
		'columns' => array( 2, 3, 4 ),
		'styles'  => 'portfolio',
	);
	$rumble_theme_blog_styles['gallery']   = array(
		'title'   => esc_html__( 'Gallery', 'rumble' ),
		'archive' => 'index-portfolio',
		'item'    => 'content-portfolio-gallery',
		'columns' => array( 2, 3, 4 ),
		'styles'  => array( 'portfolio', 'gallery' ),
	);
	$rumble_theme_blog_styles['chess']     = array(
		'title'   => esc_html__( 'Chess', 'rumble' ),
		'archive' => 'index-chess',
		'item'    => 'content-chess',
		'columns' => array( 1, 2, 3 ),
		'styles'  => 'chess',
	);
}

// Add list of blog styles to the global storage
$GLOBALS['RUMBLE_STORAGE']['blog_styles'] = $rumble_theme_blog_styles;


// Theme init priorities:
// Action 'after_setup_theme'
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options. Attention! After this step you can use only basic options (not overriden)
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
// Action 'wp_loaded'
// 1 - detect override mode. Attention! Only after this step you can use overriden options (separate values for the shop, courses, etc.)

if ( ! function_exists( 'rumble_customizer_theme_setup1' ) ) {
	add_action( 'after_setup_theme', 'rumble_customizer_theme_setup1', 1 );
	function rumble_customizer_theme_setup1() {

		// -----------------------------------------------------------------
		// -- ONLY FOR PROGRAMMERS, NOT FOR CUSTOMER
		// -- Internal theme settings
		// -----------------------------------------------------------------
		rumble_storage_set(
			'settings', array(

				'duplicate_options'      => 'child',                    // none  - use separate options for the main and the child-theme
																		// child - duplicate theme options from the main theme to the child-theme only
																		// both  - sinchronize changes in the theme options between main and child themes

				'customize_refresh'      => 'auto',                     // Refresh method for preview area in the Appearance - Customize:
																		// auto - refresh preview area on change each field with Theme Options
																		// manual - refresh only obn press button 'Refresh' at the top of Customize frame

				'max_load_fonts'         => 5,                          // Max fonts number to load from Google fonts or from uploaded fonts

				'comment_after_name'     => true,                       // Place 'comment' field after the 'name' and 'email'

				'show_author_avatar'     => true,                       // Display author's avatar in the post meta

				'icons_selector'         => 'internal',                 // Icons selector in the shortcodes:
																		//  - standard VC (very slow) or Elementor's icons selector (not support images and svg)
																		// internal - internal popup with plugin's or theme's icons list (fast and support images and svg)

				'icons_type'             => 'icons',                    // Type of icons (if 'icons_selector' is 'internal'):
																		// icons  - use font icons to present icons
																		// images - use images from theme's folder trx_addons/css/icons.png
																		// svg    - use svg from theme's folder trx_addons/css/icons.svg

				'socials_type'           => 'icons',                    // Type of socials icons (if 'icons_selector' is 'internal'):
																		// icons  - use font icons to present social networks
																		// images - use images from theme's folder trx_addons/css/icons.png
																		// svg    - use svg from theme's folder trx_addons/css/icons.svg

				'check_min_version'      => true,                       // Check if exists a .min version of .css and .js and return path to it
																		// instead the path to the original file
																		// (if debug_mode is off and modification time of the original file < time of the .min file)

				'autoselect_menu'        => true,                      // Show any menu if no menu selected in the location 'main_menu'
																		// (for example, the theme is just activated)

				'disable_jquery_ui'      => false,                      // Prevent loading custom jQuery UI libraries in the third-party plugins

				'use_mediaelements'      => true,                       // Load script "Media Elements" to play video and audio

				'tgmpa_upload'           => false,                      // Allow upload not pre-packaged plugins via TGMPA

				'allow_no_image'         => false,                      // Allow to use theme-specific image placeholder if no image present in the blog, related posts, post navigation, etc.

				'separate_schemes'       => true,                       // Save color schemes to the separate files __color_xxx.css (true) or append its to the __custom.css (false)

				'allow_fullscreen'       => false,                      // Allow cases 'fullscreen' and 'fullwide' for the body style in the Theme Options
																		// In the Page Options this styles are present always
																		// (can be removed if filter 'rumble_filter_allow_fullscreen' return false)

				'attachments_navigation' => false,                      // Add arrows on the single attachment page to navigate to the prev/next attachment

				'gutenberg_safe_mode'    => array(),                    // 'vc', 'elementor' - Prevent simultaneous editing of posts for Gutenberg and other PageBuilders (VC, Elementor)

				'gutenberg_add_context'  => false,                      // Add context to the Gutenberg editor styles with our method (if true - use if any problem with editor styles) or use native Gutenberg way via add_editor_style() (if false - used by default)

				'allow_gutenberg_blocks' => true,                       // Allow our shortcodes and widgets as blocks in the Gutenberg (not ready yet - in the development now)

				'subtitle_above_title'   => true,                       // Put subtitle above the title in the shortcodes

				'add_hide_on_xxx'        => 'replace',                  // Add our breakpoints to the Responsive section of each element
																		// 'add' - add our breakpoints after Elementor's
																		// 'replace' - add our breakpoints instead Elementor's
																		// 'none' - don't add our breakpoints (using only Elementor's)
			)
		);

		// -----------------------------------------------------------------
		// -- Theme fonts (Google and/or custom fonts)
		// -----------------------------------------------------------------

		// Fonts to load when theme start
		// It can be Google fonts or uploaded fonts, placed in the folder /css/font-face/font-name inside the theme folder
		// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'
		
		rumble_storage_set(
			'load_fonts', array(
				// Google font
				array(
					'name'   => 'Rajdhani',
					'family' => 'sans-serif',
					'styles' => '300,400,500,600,700',     // Parameter 'style' used only for the Google fonts
				),
                array(
					'name'   => 'Homemade Apple',
					'family' => 'cursive',
					'styles' => '400',     // Parameter 'style' used only for the Google fonts
				),
				// Font-face packed with theme
				array(
					'name'   => 'Montserrat',
					'family' => 'sans-serif',
				),
			)
		);

		// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
		rumble_storage_set( 'load_fonts_subset', 'latin,latin-ext' );

		rumble_storage_set(
			'theme_fonts', array(
				'p'       => array(
					'title'           => esc_html__( 'Main text', 'rumble' ),
					'description'     => esc_html__( 'Font settings of the main text of the site. Attention! For correct display of the site on mobile devices, use only units "rem", "em" or "ex"', 'rumble' ),
					'font-family'     => '"Montserrat",sans-serif',
					'font-size'       => '1rem',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.872em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0.16px',
					'margin-top'      => '0em',
					'margin-bottom'   => '1.9em',
				),
				'h1'      => array(
					'title'           => esc_html__( 'Heading 1', 'rumble' ),
					'font-family'     => '"Rajdhani",sans-serif',
					'font-size'       => '5.143em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '0.9301em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.617em',
					'margin-bottom'   => '0.4833em',
				),
				'h2'      => array(
					'title'           => esc_html__( 'Heading 2', 'rumble' ),
					'font-family'     => '"Rajdhani",sans-serif',
					'font-size'       => '4.286em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '0.91667em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.952em',
					'margin-bottom'   => '0.5619em',
				),
				'h3'      => array(
					'title'           => esc_html__( 'Heading 3', 'rumble' ),
					'font-family'     => '"Rajdhani",sans-serif',
					'font-size'       => '3.429em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '0.9792em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0px',
					'margin-top'      => '2.245em',
					'margin-bottom'   => '0.62em',
				),
				'h4'      => array(
					'title'           => esc_html__( 'Heading 4', 'rumble' ),
					'font-family'     => '"Rajdhani",sans-serif',
					'font-size'       => '2.571em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '1.0277em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0px',
					'margin-top'      => '2.6923em',
					'margin-bottom'   => '0.77em',
				),
				'h5'      => array(
					'title'           => esc_html__( 'Heading 5', 'rumble' ),
					'font-family'     => '"Rajdhani",sans-serif',
					'font-size'       => '2.143em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '1.03333em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0px',
					'margin-top'      => '2.8em',
					'margin-bottom'   => '0.73em',
				),
				'h6'      => array(
					'title'           => esc_html__( 'Heading 6', 'rumble' ),
					'font-family'     => '"Rajdhani",sans-serif',
					'font-size'       => '1.714em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '1.125em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '0px',
					'margin-top'      => '3.1em',
					'margin-bottom'   => '0.86em',
				),
				'logo'    => array(
					'title'           => esc_html__( 'Logo text', 'rumble' ),
					'description'     => esc_html__( 'Font settings of the text case of the logo', 'rumble' ),
					'font-family'     => '"Montserrat",sans-serif',
					'font-size'       => '2.357em',
					'font-weight'     => '800',
					'font-style'      => 'normal',
					'line-height'     => '1.12em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '1px',
				),
				'button'  => array(
					'title'           => esc_html__( 'Buttons', 'rumble' ),
					'font-family'     => '"Rajdhani",sans-serif',
					'font-size'       => '16px',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '22px',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '2px',
				),
				'input'   => array(
					'title'           => esc_html__( 'Input fields', 'rumble' ),
					'description'     => esc_html__( 'Font settings of the input fields, dropdowns and textareas', 'rumble' ),
					'font-family'     => 'inherit',
					'font-size'       => '1em',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em', // Attention! Firefox don't allow line-height less then 1.5em in the select
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'info'    => array(
					'title'           => esc_html__( 'Post meta', 'rumble' ),
					'description'     => esc_html__( 'Font settings of the post meta: date, counters, share, etc.', 'rumble' ),
					'font-family'     => '"Rajdhani",sans-serif',
					'font-size'       => '12px',  // Old value '13px' don't allow using 'font zoom' in the custom blog items
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '2px',
					'margin-top'      => '0.4em',
					'margin-bottom'   => '',
				),
				'menu'    => array(
					'title'           => esc_html__( 'Main menu', 'rumble' ),
					'description'     => esc_html__( 'Font settings of the main menu items', 'rumble' ),
					'font-family'     => '"Rajdhani",sans-serif',
					'font-size'       => '16px',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '1px',
				),
				'submenu' => array(
					'title'           => esc_html__( 'Dropdown menu', 'rumble' ),
					'description'     => esc_html__( 'Font settings of the dropdown menu items', 'rumble' ),
					'font-family'     => '"Rajdhani",sans-serif',
					'font-size'       => '16px',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '2.1em',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '1px',
				),
                'other'  =>array(
                    'title'           => esc_html__( 'Other font family', 'rumble' ),
                    'description'     => esc_html__( 'Decoration font', 'rumble' ),
                    'font-family'     => '"Homemade Apple",cursive',
                    'font-weight'     => '400',
                ),
			)
		);

		// -----------------------------------------------------------------
		// -- Theme colors for customizer
		// -- Attention! Inner scheme must be last in the array below
		// -----------------------------------------------------------------
		rumble_storage_set(
			'scheme_color_groups', array(
				'main'    => array(
					'title'       => esc_html__( 'Main', 'rumble' ),
					'description' => esc_html__( 'Colors of the main content area', 'rumble' ),
				),
				'alter'   => array(
					'title'       => esc_html__( 'Alter', 'rumble' ),
					'description' => esc_html__( 'Colors of the alternative blocks (sidebars, etc.)', 'rumble' ),
				),
				'extra'   => array(
					'title'       => esc_html__( 'Extra', 'rumble' ),
					'description' => esc_html__( 'Colors of the extra blocks (dropdowns, price blocks, table headers, etc.)', 'rumble' ),
				),
				'inverse' => array(
					'title'       => esc_html__( 'Inverse', 'rumble' ),
					'description' => esc_html__( 'Colors of the inverse blocks - when link color used as background of the block (dropdowns, blockquotes, etc.)', 'rumble' ),
				),
				'input'   => array(
					'title'       => esc_html__( 'Input', 'rumble' ),
					'description' => esc_html__( 'Colors of the form fields (text field, textarea, select, etc.)', 'rumble' ),
				),
			)
		);
		rumble_storage_set(
			'scheme_color_names', array(
				'bg_color'    => array(
					'title'       => esc_html__( 'Background color', 'rumble' ),
					'description' => esc_html__( 'Background color of this block in the normal state', 'rumble' ),
				),
				'bg_hover'    => array(
					'title'       => esc_html__( 'Background hover', 'rumble' ),
					'description' => esc_html__( 'Background color of this block in the hovered state', 'rumble' ),
				),
				'bd_color'    => array(
					'title'       => esc_html__( 'Border color', 'rumble' ),
					'description' => esc_html__( 'Border color of this block in the normal state', 'rumble' ),
				),
				'bd_hover'    => array(
					'title'       => esc_html__( 'Border hover', 'rumble' ),
					'description' => esc_html__( 'Border color of this block in the hovered state', 'rumble' ),
				),
				'text'        => array(
					'title'       => esc_html__( 'Text', 'rumble' ),
					'description' => esc_html__( 'Color of the plain text inside this block', 'rumble' ),
				),
				'text_dark'   => array(
					'title'       => esc_html__( 'Text dark', 'rumble' ),
					'description' => esc_html__( 'Color of the dark text (bold, header, etc.) inside this block', 'rumble' ),
				),
				'text_light'  => array(
					'title'       => esc_html__( 'Text light', 'rumble' ),
					'description' => esc_html__( 'Color of the light text (post meta, etc.) inside this block', 'rumble' ),
				),
				'text_link'   => array(
					'title'       => esc_html__( 'Link', 'rumble' ),
					'description' => esc_html__( 'Color of the links inside this block', 'rumble' ),
				),
				'text_hover'  => array(
					'title'       => esc_html__( 'Link hover', 'rumble' ),
					'description' => esc_html__( 'Color of the hovered state of links inside this block', 'rumble' ),
				),
				'text_link2'  => array(
					'title'       => esc_html__( 'Link 2', 'rumble' ),
					'description' => esc_html__( 'Color of the accented texts (areas) inside this block', 'rumble' ),
				),
				'text_hover2' => array(
					'title'       => esc_html__( 'Link 2 hover', 'rumble' ),
					'description' => esc_html__( 'Color of the hovered state of accented texts (areas) inside this block', 'rumble' ),
				),
				'text_link3'  => array(
					'title'       => esc_html__( 'Link 3', 'rumble' ),
					'description' => esc_html__( 'Color of the other accented texts (buttons) inside this block', 'rumble' ),
				),
				'text_hover3' => array(
					'title'       => esc_html__( 'Link 3 hover', 'rumble' ),
					'description' => esc_html__( 'Color of the hovered state of other accented texts (buttons) inside this block', 'rumble' ),
				),
			)
		);
		rumble_storage_set(
			'schemes', array(

				// Color scheme: 'default'
				'default' => array(
					'title'    => esc_html__( 'Default', 'rumble' ),
					'internal' => true,
					'colors'   => array(

						// Whole block border and background
						'bg_color'         => '#f1ede1', //+
						'bd_color'         => '#cac5b6', //+

						// Text and links colors
						'text'             => '#5b5853', //+
						'text_light'       => '#5b5853', //+
						'text_dark'        => '#16120f', //+
						'text_link'        => '#16120f', //+
						'text_hover'       => '#d72323', //+
						'text_link2'       => '#16120f', //+
						'text_hover2'      => '#d72323', //+
						'text_link3'       => '#be2424', //+
						'text_hover3'      => '#625f5a', //+

						// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
						'alter_bg_color'   => '#e9e5d8', //+
						'alter_bg_hover'   => '#dfdacb', //+
						'alter_bd_color'   => '#cac5b6', //+
						'alter_bd_hover'   => '#16120f', //+
						'alter_text'       => '#5b5853', //+
						'alter_light'      => '#5b5853', //+
						'alter_dark'       => '#16120f', //+
						'alter_link'       => '#d72323', //+
						'alter_hover'      => '#16120f', //+
						'alter_link2'      => '#929292', //+
						'alter_hover2'     => '#51504B', //+
						'alter_link3'      => '#929292', //+
						'alter_hover3'     => '#eaa199', //+

						// Extra blocks (submenu, tabs, color blocks, etc.)
						'extra_bg_color'   => '#16120f', //+
						'extra_bg_hover'   => '#dbd7ca', //+
						'extra_bd_color'   => '#3b3632', //+
						'extra_bd_hover'   => '#24201c', //+
						'extra_text'       => '#5b5853', //+
						'extra_light'      => '#5b5853', //+
						'extra_dark'       => '#79736c', //+
						'extra_link'       => '#f1ede1', //+
						'extra_hover'      => '#79736c', //+
						'extra_link2'      => '#f1ede1', //+
						'extra_hover2'     => '#8be77c',
						'extra_link3'      => '#ddb837',
						'extra_hover3'     => '#cdc8be', //+

						// Input fields (form's fields and textarea)
						'input_bg_color'   => '#e1ddcf', //+
						'input_bg_hover'   => '#e1ddcf', //+
						'input_bd_color'   => '#e1decf', //+
						'input_bd_hover'   => '#cac5b6', //+
						'input_text'       => '#5b5853', //+
						'input_light'      => '#5b5853', //+
						'input_dark'       => '#16120f', //+

						// Inverse blocks (text and links on the 'text_link' background)
						'inverse_bd_color' => '#e1ddcf', //+
						'inverse_bd_hover' => '#e1ddcf', //+
						'inverse_text'     => '#f1ede1', //+
						'inverse_light'    => '#c21c1c', //+
						'inverse_dark'     => '#16120f', //+
						'inverse_link'     => '#f1ede1', //+
						'inverse_hover'    => '#16120f', //+
					),
				),

				// Color scheme: 'dark'
				'dark'    => array(
					'title'    => esc_html__( 'Dark', 'rumble' ),
					'internal' => true,
					'colors'   => array(

						// Whole block border and background
						'bg_color'         => '#24211c', //+
						'bd_color'         => '#3b3632', //+

						// Text and links colors
						'text'             => '#929292', //+
						'text_light'       => '#929292', //+
						'text_dark'        => '#f1ede1', //+
						'text_link'        => '#f1ede1', //+
						'text_hover'       => '#d72323', //+
						'text_link2'       => '#1c1916', //+
						'text_hover2'      => '#16120f', //+
						'text_link3'       => '#be2424', //+
						'text_hover3'      => '#3A3633', //+

						// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
						'alter_bg_color'   => '#16120f', //+
						'alter_bg_hover'   => '#2f2e26', //+
						'alter_bd_color'   => '#3b3632', //+
						'alter_bd_hover'   => '#16120f', //+
						'alter_text'       => '#5b5853', //+
						'alter_light'      => '#5b5853', //+
						'alter_dark'       => '#f1ede1', //+
						'alter_link'       => '#f1ede1', //+
						'alter_hover'      => '#d72323', //+
						'alter_link2'      => '#f1ede1', //+
						'alter_hover2'     => '#51504B', //+
						'alter_link3'      => '#929292', //+
						'alter_hover3'     => '#F7C0BA', //+

						// Extra blocks (submenu, tabs, color blocks, etc.)
						'extra_bg_color'   => '#f1ede1', //+
						'extra_bg_hover'   => '#f3f5f7', //+
						'extra_bd_color'   => '#cac5b6', //+
						'extra_bd_hover'   => '#24201c', //+
						'extra_text'       => '#252525', //+
						'extra_light'      => '#7c7c7a', //+
						'extra_dark'       => '#5b5853', //+
						'extra_link'       => '#d72323', //+
						'extra_hover'      => '#929292', //+
						'extra_link2'      => '#f1ede1', //+
						'extra_hover2'     => '#8be77c',
						'extra_link3'      => '#ddb837',
						'extra_hover3'     => '#3b3632', //+

						// Input fields (form's fields and textarea)
						'input_bg_color'   => '#24211c', //+
						'input_bg_hover'   => '#24211c', //+
						'input_bd_color'   => '#3b3632', //+
						'input_bd_hover'   => '#3b3632', //+
						'input_text'       => '#5b5853', //+
						'input_light'      => '#f1ede1', //+
						'input_dark'       => '#ffffff', //+

						// Inverse blocks (text and links on the 'text_link' background)
						'inverse_bd_color' => '#be2424', //+
						'inverse_bd_hover' => '#e1ddcf', //+
						'inverse_text'     => '#f1ede1', //+
						'inverse_light'    => '#c21c1c', //+
						'inverse_dark'     => '#252525', //+
						'inverse_link'     => '#16120f', //+
						'inverse_hover'    => '#f1ede1', //+
					),
				),

				// Color scheme: 'default_blue'
				'default_blue'    => array(
					'title'    => esc_html__( 'Default Blue', 'rumble' ),
					'internal' => true,
					'colors'   => array(

						// Whole block border and background
						'bg_color'         => '#F9F9FC', //+
						'bd_color'         => '#E1E1EB', //+

						// Text and links colors
						'text'             => '#7B7D88', //+
						'text_light'       => '#7B7D88', //+
						'text_dark'        => '#16120F', //+
						'text_link'        => '#16120f', //+
						'text_hover'       => '#2454D7', //+
						'text_link2'       => '#16120f', //+
						'text_hover2'      => '#2454D7', //+
						'text_link3'       => '#be2424', //+
						'text_hover3'      => '#96A9DE', //+

						// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
						'alter_bg_color'   => '#F2F2F7', //+
						'alter_bg_hover'   => '#dfdacb', //+
						'alter_bd_color'   => '#E1E1EB', //+
						'alter_bd_hover'   => '#16120f', //+
						'alter_text'       => '#7B7D88', //+
						'alter_light'      => '#7B7D88', //+
						'alter_dark'       => '#16120F', //+
						'alter_link'       => '#2454D7', //+
						'alter_hover'      => '#16120f', //+
						'alter_link2'      => '#929292', //+
						'alter_hover2'     => '#51504B', //+
						'alter_link3'      => '#929292', //+
						'alter_hover3'     => '#eaa199', //+

						// Extra blocks (submenu, tabs, color blocks, etc.)
						'extra_bg_color'   => '#16120f', //+
						'extra_bg_hover'   => '#dbd7ca', //+
						'extra_bd_color'   => '#E1E1EB', //+
						'extra_bd_hover'   => '#24201c', //+
						'extra_text'       => '#7B7D88', //+
						'extra_light'      => '#7B7D88', //+
						'extra_dark'       => '#79736c', //+
						'extra_link'       => '#F8F4F2', //+
						'extra_hover'      => '#ffffff', //+
						'extra_link2'      => '#F8F4F2', //+
						'extra_hover2'     => '#8be77c',
						'extra_link3'      => '#ddb837',
						'extra_hover3'     => '#cdc8be', //+

						// Input fields (form's fields and textarea)
						'input_bg_color'   => '#E1E1EB', //+
						'input_bg_hover'   => '#e1ddcf', //+
						'input_bd_color'   => '#e1decf', //+
						'input_bd_hover'   => '#3B3632', //+
						'input_text'       => '#7B7D88', //+
						'input_light'      => '#7B7D88', //+
						'input_dark'       => '#16120f', //+

						// Inverse blocks (text and links on the 'text_link' background)
						'inverse_bd_color' => '#E1E1EB', //+
						'inverse_bd_hover' => '#e1ddcf', //+
						'inverse_text'     => '#F8F4F2', //+
						'inverse_light'    => '#c21c1c', //+
						'inverse_dark'     => '#16120f', //+
						'inverse_link'     => '#F8F4F2', //+
						'inverse_hover'    => '#16120f', //+
					),
				),

				// Color scheme: 'dark_blue'
				'dark_blue'    => array(
					'title'    => esc_html__( 'Dark Blue', 'rumble' ),
					'internal' => true,
					'colors'   => array(

						// Whole block border and background
						'bg_color'         => '#16120F', //+
						'bd_color'         => '#3B3632', //+

						// Text and links colors
						'text'             => '#7B7D88', //+
						'text_light'       => '#7B7D88', //+
						'text_dark'        => '#F8F4F2', //+
						'text_link'        => '#F8F4F2', //+
						'text_hover'       => '#2454D7', //+
						'text_link2'       => '#F8F4F2', //+
						'text_hover2'      => '#2454D7', //+
						'text_link3'       => '#be2424', //+
						'text_hover3'      => '#96A9DE', //+

						// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
						'alter_bg_color'   => '#F2F2F7', //+
						'alter_bg_hover'   => '#dfdacb', //+
						'alter_bd_color'   => '#3B3632', //+
						'alter_bd_hover'   => '#F8F4F2', //+
						'alter_text'       => '#7B7D88', //+
						'alter_light'      => '#7B7D88', //+
						'alter_dark'       => '#F8F4F2', //+
						'alter_link'       => '#2454D7', //+
						'alter_hover'      => '#F8F4F2', //+
						'alter_link2'      => '#929292', //+
						'alter_hover2'     => '#51504B', //+
						'alter_link3'      => '#929292', //+
						'alter_hover3'     => '#eaa199', //+

						// Extra blocks (submenu, tabs, color blocks, etc.)
						'extra_bg_color'   => '#F8F4F2', //+
						'extra_bg_hover'   => '#dbd7ca', //+
						'extra_bd_color'   => '#3b3632', //+
						'extra_bd_hover'   => '#24201c', //+
						'extra_text'       => '#7B7D88', //+
						'extra_light'      => '#7B7D88', //+
						'extra_dark'       => '#F1EDE1', //+
						'extra_link'       => '#F8F4F2', //+
						'extra_hover'      => '#ffffff', //+
						'extra_link2'      => '#F8F4F2', //+
						'extra_hover2'     => '#8be77c',
						'extra_link3'      => '#ddb837',
						'extra_hover3'     => '#3B3632', //+

						// Input fields (form's fields and textarea)
						'input_bg_color'   => '#e1ddcf', //+
						'input_bg_hover'   => '#e1ddcf', //+
						'input_bd_color'   => '#e1decf', //+
						'input_bd_hover'   => '#3B3632', //+
						'input_text'       => '#7B7D88', //+
						'input_light'      => '#7B7D88', //+
						'input_dark'       => '#F8F4F2', //+

						// Inverse blocks (text and links on the 'text_link' background)
						'inverse_bd_color' => '#e1ddcf', //+
						'inverse_bd_hover' => '#e1ddcf', //+
						'inverse_text'     => '#F8F4F2', //+
						'inverse_light'    => '#c21c1c', //+
						'inverse_dark'     => '#F8F4F2', //+
						'inverse_link'     => '#F8F4F2', //+
						'inverse_hover'    => '#F8F4F2', //+
					),
				),

				// Color scheme: 'default_orange'
				'default_orange'    => array(
					'title'    => esc_html__( 'Default Orange', 'rumble' ),
					'internal' => true,
					'colors'   => array(

						// Whole block border and background
						'bg_color'         => '#F4EDE6', //+
						'bd_color'         => '#CAC5B6', //+

						// Text and links colors
						'text'             => '#5B5853', //+
						'text_light'       => '#5B5853', //+
						'text_dark'        => '#16120F', //+
						'text_link'        => '#f1ede1', //+
						'text_hover'       => '#EA690A', //+
						'text_link2'       => '#16120f', //+
						'text_hover2'      => '#EA690A', //+
						'text_link3'       => '#be2424', //+
						'text_hover3'      => '#EA690A', //+

						// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
						'alter_bg_color'   => '#EBE3DA', //+
						'alter_bg_hover'   => '#dfdacb', //+
						'alter_bd_color'   => '#CAC5B6', //+
						'alter_bd_hover'   => '#16120f', //+
						'alter_text'       => '#5B5853', //+
						'alter_light'      => '#5B5853', //+
						'alter_dark'       => '#16120F', //+
						'alter_link'       => '#EA690A', //+
						'alter_hover'      => '#16120f', //+
						'alter_link2'      => '#929292', //+
						'alter_hover2'     => '#51504B', //+
						'alter_link3'      => '#929292', //+
						'alter_hover3'     => '#eaa199', //+

						// Extra blocks (submenu, tabs, color blocks, etc.)
						'extra_bg_color'   => '#16120f', //+
						'extra_bg_hover'   => '#dbd7ca', //+
						'extra_bd_color'   => '#CAC5B6', //+
						'extra_bd_hover'   => '#24201c', //+
						'extra_text'       => '#5B5853', //+
						'extra_light'      => '#5B5853', //+
						'extra_dark'       => '#79736c', //+
						'extra_link'       => '#f1ede1', //+
						'extra_hover'      => '#79736C', //+
						'extra_link2'      => '#F8F4F2', //+
						'extra_hover2'     => '#8be77c',
						'extra_link3'      => '#ddb837',
						'extra_hover3'     => '#3B3632', //+

						// Input fields (form's fields and textarea)
						'input_bg_color'   => '#e1ddcf', //+
						'input_bg_hover'   => '#e1ddcf', //+
						'input_bd_color'   => '#e1decf', //+
						'input_bd_hover'   => '#CAC5B6', //+
						'input_text'       => '#5B5853', //+
						'input_light'      => '#5B5853', //+
						'input_dark'       => '#16120f', //+

						// Inverse blocks (text and links on the 'text_link' background)
						'inverse_bd_color' => '#e1ddcf', //+
						'inverse_bd_hover' => '#e1ddcf', //+
						'inverse_text'     => '#F8F4F2', //+
						'inverse_light'    => '#c21c1c', //+
						'inverse_dark'     => '#16120f', //+
						'inverse_link'     => '#F8F4F2', //+
						'inverse_hover'    => '#16120f', //+
					),
				),

				// Color scheme: 'dark_orange'
				'dark_orange'    => array(
					'title'    => esc_html__( 'Dark Orange', 'rumble' ),
					'internal' => true,
					'colors'   => array(

						// Whole block border and background
						'bg_color'         => '#F4EDE6', //+
						'bd_color'         => '#CAC5B6', //+

						// Text and links colors
						'text'             => '#5B5853', //+
						'text_light'       => '#5B5853', //+
						'text_dark'        => '#F8F4F2', //+
						'text_link'        => '#f1ede1', //+
						'text_hover'       => '#EA690A', //+
						'text_link2'       => '#F8F4F2', //+
						'text_hover2'      => '#EA690A', //+
						'text_link3'       => '#be2424', //+
						'text_hover3'      => '#EA690A', //+

						// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
						'alter_bg_color'   => '#16120F', //+
						'alter_bg_hover'   => '#dfdacb', //+
						'alter_bd_color'   => '#EBE3DA', //+
						'alter_bd_hover'   => '#F8F4F2', //+
						'alter_text'       => '#5B5853', //+
						'alter_light'      => '#5B5853', //+
						'alter_dark'       => '#16120F', //+
						'alter_link'       => '#EA690A', //+
						'alter_hover'      => '#16120F', //+
						'alter_link2'      => '#929292', //+
						'alter_hover2'     => '#51504B', //+
						'alter_link3'      => '#929292', //+
						'alter_hover3'     => '#eaa199', //+

						// Extra blocks (submenu, tabs, color blocks, etc.)
						'extra_bg_color'   => '#EBE3DA', //+
						'extra_bg_hover'   => '#dbd7ca', //+
						'extra_bd_color'   => '#CAC5B6', //+
						'extra_bd_hover'   => '#24201c', //+
						'extra_text'       => '#5B5853', //+
						'extra_light'      => '#5B5853', //+
						'extra_dark'       => '#F1EDE1', //+
						'extra_link'       => '#F8F4F2', //+
						'extra_hover'      => '#79736C', //+
						'extra_link2'      => '#F8F4F2', //+
						'extra_hover2'     => '#8be77c',
						'extra_link3'      => '#ddb837',
						'extra_hover3'     => '#cdc8be', //+

						// Input fields (form's fields and textarea)
						'input_bg_color'   => '#e1ddcf', //+
						'input_bg_hover'   => '#e1ddcf', //+
						'input_bd_color'   => '#e1decf', //+
						'input_bd_hover'   => '#3B3632', //+
						'input_text'       => '#5B5853', //+
						'input_light'      => '#5B5853', //+
						'input_dark'       => '#F8F4F2', //+

						// Inverse blocks (text and links on the 'text_link' background)
						'inverse_bd_color' => '#e1ddcf', //+
						'inverse_bd_hover' => '#e1ddcf', //+
						'inverse_text'     => '#F8F4F2', //+
						'inverse_light'    => '#c21c1c', //+
						'inverse_dark'     => '#F8F4F2', //+
						'inverse_link'     => '#F8F4F2', //+
						'inverse_hover'    => '#F8F4F2', //+
					),
				),

			)
		);

        rumble_storage_set( 'schemes_original', rumble_storage_get( 'schemes' ) );

		// Simple scheme editor: lists the colors to edit in the "Simple" mode.
		// For each color you can set the array of 'slave' colors and brightness factors that are used to generate new values,
		// when 'main' color is changed
		// Leave 'slave' arrays empty if your scheme does not have a color dependency
		rumble_storage_set(
			'schemes_simple', array(
				'text_link'        => array(
					'alter_hover'      => 1,
					'extra_link'       => 1,
					'inverse_bd_color' => 0.85,
					'inverse_bd_hover' => 0.7,
				),
				'text_hover'       => array(
					'alter_link'  => 1,
					'extra_hover' => 1,
				),
				'text_link2'       => array(
					'alter_hover2' => 1,
					'extra_link2'  => 1,
				),
				'text_hover2'      => array(
					'alter_link2'  => 1,
					'extra_hover2' => 1,
				),
				'text_link3'       => array(
					'alter_hover3' => 1,
					'extra_link3'  => 1,
				),
				'text_hover3'      => array(
					'alter_link3'  => 1,
					'extra_hover3' => 1,
				),
				'alter_link'       => array(),
				'alter_hover'      => array(),
				'alter_link2'      => array(),
				'alter_hover2'     => array(),
				'alter_link3'      => array(),
				'alter_hover3'     => array(),
				'extra_link'       => array(),
				'extra_hover'      => array(),
				'extra_link2'      => array(),
				'extra_hover2'     => array(),
				'extra_link3'      => array(),
				'extra_hover3'     => array(),
				'inverse_bd_color' => array(),
				'inverse_bd_hover' => array(),
			)
		);

		// Additional colors for each scheme
		// Parameters:	'color' - name of the color from the scheme that should be used as source for the transformation
		//				'alpha' - to make color transparent (0.0 - 1.0)
		//				'hue', 'saturation', 'brightness' - inc/dec value for each color's component
		rumble_storage_set(
			'scheme_colors_add', array(
				'bg_color_0'        => array(
					'color' => 'bg_color',
					'alpha' => 0,
				),
				'bg_color_02'       => array(
					'color' => 'bg_color',
					'alpha' => 0.2,
				),
				'bg_color_07'       => array(
					'color' => 'bg_color',
					'alpha' => 0.7,
				),
                'bg_color_04'       => array(
					'color' => 'bg_color',
					'alpha' => 0.4,
				),
				'bg_color_08'       => array(
					'color' => 'bg_color',
					'alpha' => 0.8,
				),
				'bg_color_09'       => array(
					'color' => 'bg_color',
					'alpha' => 0.9,
				),
				'alter_bg_color_07' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.7,
				),
                'alter_bd_hover_07' => array(
					'color' => 'alter_bd_hover',
					'alpha' => 0.7,
				),
				'alter_bg_color_04' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.4,
				),
				'alter_bg_color_00' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0,
				),
				'alter_bg_color_02' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.2,
				),
                'text_dark_07' => array(
					'color' => 'text_dark',
					'alpha' => 0.7,
				),
                'extra_dark_07' => array(
					'color' => 'extra_dark',
					'alpha' => 0.7,
				),
				'alter_bd_color_02' => array(
					'color' => 'alter_bd_color',
					'alpha' => 0.2,
				),
				'alter_link_02'     => array(
					'color' => 'alter_link',
					'alpha' => 0.2,
				),
                'alter_link_04'     => array(
					'color' => 'alter_link',
					'alpha' => 0.4,
				),
				'alter_link_07'     => array(
					'color' => 'alter_link',
					'alpha' => 0.7,
				),
				'extra_bg_color_05' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.5,
				),
				'extra_bg_color_07' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.7,
				),
				'extra_link_02'     => array(
					'color' => 'extra_link',
					'alpha' => 0.2,
				),
				'extra_link_07'     => array(
					'color' => 'extra_link',
					'alpha' => 0.7,
				),
				'text_link_02'      => array(
					'color' => 'text_link',
					'alpha' => 0.2,
				),
				'text_link_07'      => array(
					'color' => 'text_link',
					'alpha' => 0.7,
				),
				'text_link_blend'   => array(
					'color'      => 'text_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'alter_link_blend'  => array(
					'color'      => 'alter_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
			)
		);

		// Parameters to set order of schemes in the css
		rumble_storage_set(
			'schemes_sorted', array(
				'color_scheme',
				'header_scheme',
				'sidebar_scheme',
				'footer_scheme',
			)
		);

		// -----------------------------------------------------------------
		// -- Theme specific thumb sizes
		// -----------------------------------------------------------------
		rumble_storage_set(
			'theme_thumbs', apply_filters(
				'rumble_filter_add_thumb_sizes', array(
					// Width of the image is equal to the content area width (without sidebar)
					// Height is fixed
					'rumble-thumb-huge'        => array(
						'size'  => array( 1170, 658, true ),
						'title' => esc_html__( 'Huge image', 'rumble' ),
						'subst' => 'trx_addons-thumb-huge',
					),
					// Width of the image is equal to the content area width (with sidebar)
					// Height is fixed
					'rumble-thumb-big'         => array(
						'size'  => array( 765, 435, true ),
						'title' => esc_html__( 'Large image', 'rumble' ),
						'subst' => 'trx_addons-thumb-big',
					),

					// Width of the image is equal to the 1/3 of the content area width (without sidebar)
					// Height is fixed
					'rumble-thumb-med'         => array(
						'size'  => array( 406, 250, true ),
						'title' => esc_html__( 'Medium image', 'rumble' ),
						'subst' => 'trx_addons-thumb-medium',
					),

					// Small square image (for avatars in comments, etc.)
					'rumble-thumb-tiny'        => array(
						'size'  => array( 90, 90, true ),
						'title' => esc_html__( 'Small square avatar', 'rumble' ),
						'subst' => 'trx_addons-thumb-tiny',
					),

					// Width of the image is equal to the content area width (with sidebar)
					// Height is proportional (only downscale, not crop)
					'rumble-thumb-masonry-big' => array(
						'size'  => array( 765, 0, false ),     // Only downscale, not crop
						'title' => esc_html__( 'Masonry Large (scaled)', 'rumble' ),
						'subst' => 'trx_addons-thumb-masonry-big',
					),

					// Width of the image is equal to the 1/3 of the full content area width (without sidebar)
					// Height is proportional (only downscale, not crop)
					'rumble-thumb-masonry'     => array(
						'size'  => array( 370, 0, false ),     // Only downscale, not crop
						'title' => esc_html__( 'Masonry (scaled)', 'rumble' ),
						'subst' => 'trx_addons-thumb-masonry',
					),
                    'rumble-thumb-team'     => array(
						'size'  => array( 600, 764, true ),     // Only downscale, not crop
						'title' => esc_html__( 'Team', 'rumble' ),
						'subst' => 'trx_addons-thumb-team',
					),
                    'rumble-thumb-services'     => array(
						'size'  => array( 406, 512, true ),     // Only downscale, not crop
						'title' => esc_html__( 'Services', 'rumble' ),
						'subst' => 'trx_addons-thumb-services',
					),
                    'rumble-thumb-news'     => array(
						'size'  => array( 640, 560, true ),     // Only downscale, not crop
						'title' => esc_html__( 'News', 'rumble' ),
						'subst' => 'trx_addons-thumb-news',
					),
                    'rumble-thumb-boxer'     => array(
						'size'  => array( 842, 560, true ),     // Only downscale, not crop
						'title' => esc_html__( 'Boxer', 'rumble' ),
						'subst' => 'trx_addons-thumb-boxer',
					),
                    'rumble-thumb-match'     => array(
						'size'  => array( 366, 260, true ),     // Only downscale, not crop
						'title' => esc_html__( 'Match', 'rumble' ),
						'subst' => 'trx_addons-thumb-match',
					),
				)
			)
		);
	}
}




//------------------------------------------------------------------------
// One-click import support
//------------------------------------------------------------------------

// Set theme specific importer options
if ( ! function_exists( 'rumble_importer_set_options' ) ) {
	add_filter( 'trx_addons_filter_importer_options', 'rumble_importer_set_options', 9 );
	function rumble_importer_set_options( $options = array() ) {
		if ( is_array( $options ) ) {
			// Save or not installer's messages to the log-file
			$options['debug'] = false;
			// Allow import/export functionality
			$options['allow_import'] = true;
			$options['allow_export'] = false;
			// Prepare demo data
			$options['demo_url'] = esc_url( rumble_get_protocol() . '://demofiles.ancorathemes.com/rumble' );
			// Required plugins
			$options['required_plugins'] = array_keys( rumble_storage_get( 'required_plugins' ) );
			// Set number of thumbnails (usually 3 - 5) to regenerate at once when its imported (if demo data was zipped without cropped images)
			// Set 0 to prevent regenerate thumbnails (if demo data archive is already contain cropped images)
			$options['regenerate_thumbnails'] = 0;
			// Default demo
			$options['files']['default']['title']       = esc_html__( 'Rumble Demo', 'rumble' );
			$options['files']['default']['domain_dev']  = esc_url( rumble_get_protocol() . '://rumble.ancorathemes.com' );       // Developers domain
			$options['files']['default']['domain_demo'] = esc_url( rumble_get_protocol() . '://rumble.ancorathemes.com' );       // Demo-site domain
			
			// The array with theme-specific banners, displayed during demo-content import.
			// If array with banners is empty - the banners are uploaded directly from demo-content server.
			$options['banners'] = array();
		}
		return $options;
	}
}


//------------------------------------------------------------------------
// OCDI support
//------------------------------------------------------------------------

// Set theme specific OCDI options
if ( ! function_exists( 'rumble_ocdi_set_options' ) ) {
	add_filter( 'trx_addons_filter_ocdi_options', 'rumble_ocdi_set_options', 9 );
	function rumble_ocdi_set_options( $options = array() ) {
		if ( is_array( $options ) ) {
			// Prepare demo data
			$options['demo_url'] = esc_url( rumble_get_protocol() . '://demofiles.ancorathemes.com/rumble/' );
			// Required plugins
			$options['required_plugins'] = array_keys( rumble_storage_get( 'required_plugins' ) );
			// Demo-site domain
			$options['files']['ocdi']['title']       = esc_html__( 'Rumble OCDI Demo', 'rumble' );
			$options['files']['ocdi']['domain_demo'] = esc_url( 'http://rumble.ancorathemes.com' );
		}
		return $options;
	}
}


// -----------------------------------------------------------------
// -- Theme options for customizer
// -----------------------------------------------------------------
if ( ! function_exists( 'rumble_create_theme_options' ) ) {

	function rumble_create_theme_options() {

		// Message about options override.
		// Attention! Not need esc_html() here, because this message put in wp_kses_data() below
		$msg_override = __( 'Attention! Some of these options can be overridden in the following sections (Blog, Plugins settings, etc.) or in the settings of individual pages. If you changed such parameter and nothing happened on the page, this option may be overridden in the corresponding section or in the Page Options of this page. These options are marked with an asterisk (*) in the title.', 'rumble' );

		// Color schemes number: if < 2 - hide fields with selectors
		$hide_schemes = count( rumble_storage_get( 'schemes' ) ) < 2;

		rumble_storage_set(

			'options', array(

				// 'Logo & Site Identity'
				//---------------------------------------------
				'title_tagline'                 => array(
					'title'    => esc_html__( 'Logo & Site Identity', 'rumble' ),
					'desc'     => '',
					'priority' => 10,
					'type'     => 'section',
				),
				'logo_info'                     => array(
					'title'    => esc_html__( 'Logo Settings', 'rumble' ),
					'desc'     => '',
					'priority' => 20,
					'qsetup'   => esc_html__( 'General', 'rumble' ),
					'type'     => 'info',
				),
				'logo_text'                     => array(
					'title'    => esc_html__( 'Use Site Name as Logo', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Use the site title and tagline as a text logo if no image is selected', 'rumble' ) ),
					'class'    => 'rumble_column-1_2 rumble_new_row',
					'priority' => 30,
					'std'      => 1,
					'qsetup'   => esc_html__( 'General', 'rumble' ),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'logo_retina_enabled'           => array(
					'title'    => esc_html__( 'Allow retina display logo', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Show fields to select logo images for Retina display', 'rumble' ) ),
					'class'    => 'rumble_column-1_2',
					'priority' => 40,
					'refresh'  => false,
					'std'      => 0,
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'logo_zoom'                     => array(
					'title'   => esc_html__( 'Logo zoom', 'rumble' ),
					'desc'    => wp_kses(
									__( 'Zoom the logo (set 1 to leave original size).', 'rumble' )
									. ' <br>'
									. __( 'Attention! For this parameter to affect images, their max-height should be specified in "em" instead of "px" when creating a header.', 'rumble' )
									. ' <br>'
									. __( 'In this case maximum size of logo depends on the actual size of the picture.', 'rumble' ), 'rumble_kses_content'
								),
					'std'     => 1,
					'min'     => 0.2,
					'max'     => 2,
					'step'    => 0.1,
					'refresh' => false,
					'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'slider',
				),
				// Parameter 'logo' was replaced with standard WordPress 'custom_logo'
				'logo_retina'                   => array(
					'title'      => esc_html__( 'Logo for Retina', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'rumble' ) ),
					'class'      => 'rumble_column-1_2',
					'priority'   => 70,
					'dependency' => array(
						'logo_retina_enabled' => array( 1 ),
					),
					'std'        => '',
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'image',
				),
				'logo_mobile_header'            => array(
					'title' => esc_html__( 'Logo for the mobile header', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Select or upload site logo to display it in the mobile header (if enabled in the section "Header - Header mobile"', 'rumble' ) ),
					'class' => 'rumble_column-1_2 rumble_new_row',
					'std'   => '',
					'type'  => 'image',
				),
				'logo_mobile_header_retina'     => array(
					'title'      => esc_html__( 'Logo for the mobile header on Retina', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'rumble' ) ),
					'class'      => 'rumble_column-1_2',
					'dependency' => array(
						'logo_retina_enabled' => array( 1 ),
					),
					'std'        => '',
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'image',
				),
				'logo_mobile'                   => array(
					'title' => esc_html__( 'Logo for the mobile menu', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Select or upload site logo to display it in the mobile menu', 'rumble' ) ),
					'class' => 'rumble_column-1_2 rumble_new_row',
					'std'   => '',
					'type'  => 'image',
				),
				'logo_mobile_retina'            => array(
					'title'      => esc_html__( 'Logo mobile on Retina', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'rumble' ) ),
					'class'      => 'rumble_column-1_2',
					'dependency' => array(
						'logo_retina_enabled' => array( 1 ),
					),
					'std'        => '',
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'image',
				),



				// 'General settings'
				//---------------------------------------------
				'general'                       => array(
					'title'    => esc_html__( 'General', 'rumble' ),
					'desc'     => wp_kses_data( $msg_override ),
					'priority' => 20,
					'type'     => 'section',
				),

				'general_layout_info'           => array(
					'title'  => esc_html__( 'Layout', 'rumble' ),
					'desc'   => '',
					'qsetup' => esc_html__( 'General', 'rumble' ),
					'type'   => 'info',
				),
				'body_style'                    => array(
					'title'    => esc_html__( 'Body style', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select width of the body content', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'qsetup'   => esc_html__( 'General', 'rumble' ),
					'refresh'  => false,
					'std'      => 'wide',
					'options'  => rumble_get_list_body_styles( false ),
					'type'     => 'select',
				),
				'page_width'                    => array(
					'title'      => esc_html__( 'Page width', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Total width of the site content and sidebar (in pixels). If empty - use default width', 'rumble' ) ),
					'dependency' => array(
						'body_style' => array( 'boxed', 'wide' ),
					),
					'std'        => 1278,
					'min'        => 1000,
					'max'        => 1400,
					'step'       => 10,
					'refresh'    => false,
					'customizer' => 'page',               // SASS variable's name to preview changes 'on fly'
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'slider',
				),
				'page_boxed_extra'             => array(
					'title'      => esc_html__( 'Boxed page extra spaces', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Width of the extra side space on boxed pages', 'rumble' ) ),
					'dependency' => array(
						'body_style' => array( 'boxed' ),
					),
					'std'        => 131,
					'min'        => 0,
					'max'        => 300,
					'step'       => 10,
					'refresh'    => false,
					'customizer' => 'page_boxed_extra',   // SASS variable's name to preview changes 'on fly'
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'slider',
				),
				'boxed_bg_image'                => array(
					'title'      => esc_html__( 'Boxed bg image', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select or upload image, used as background in the boxed body', 'rumble' ) ),
					'dependency' => array(
						'body_style' => array( 'boxed' ),
					),
					'override'   => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'std'        => '',
					'qsetup'     => esc_html__( 'General', 'rumble' ),
					'type'       => 'image',
				),
				'remove_margins'                => array(
					'title'    => esc_html__( 'Remove margins', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Remove margins above and below the content area', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'refresh'  => false,
					'std'      => 0,
					'type'     => 'checkbox',
				),

				'general_sidebar_info'          => array(
					'title' => esc_html__( 'Sidebar', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'sidebar_position'              => array(
					'title'    => esc_html__( 'Sidebar position', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select position to show sidebar', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page',		// Override parameters for single posts moved to the 'sidebar_position_single'
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'std'      => 'right',
					'qsetup'   => esc_html__( 'General', 'rumble' ),
					'options'  => array(),
					'type'     => 'switch',
				),
				'sidebar_position_ss'       => array(
					'title'    => esc_html__( 'Sidebar position on the small screen', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select position to move sidebar on the small screen - above or below the content', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page',		// Override parameters for single posts moved to the 'sidebar_position_ss_single'
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'dependency' => array(
						'sidebar_position' => array( '^hide' ),
					),
					'std'      => 'below',
					'qsetup'   => esc_html__( 'General', 'rumble' ),
					'options'  => array(),
					'type'     => 'switch',
				),
				'sidebar_widgets'               => array(
					'title'      => esc_html__( 'Sidebar widgets', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select default widgets to show in the sidebar', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page',		// Override parameters for single posts moved to the 'sidebar_widgets_single'
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'dependency' => array(
						'sidebar_position' => array( 'left', 'right' ),
					),
					'std'        => 'sidebar_widgets',
					'options'    => array(),
					'qsetup'     => esc_html__( 'General', 'rumble' ),
					'type'       => 'select',
				),
				'sidebar_width'                 => array(
					'title'      => esc_html__( 'Sidebar width', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Width of the sidebar (in pixels). If empty - use default width', 'rumble' ) ),
					'std'        => 406,
					'min'        => 150,
					'max'        => 500,
					'step'       => 10,
					'refresh'    => false,
					'customizer' => 'sidebar',      // SASS variable's name to preview changes 'on fly'
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'slider',
				),
				'sidebar_gap'                   => array(
					'title'      => esc_html__( 'Sidebar gap', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Gap between content and sidebar (in pixels). If empty - use default gap', 'rumble' ) ),
					'std'        => 30,
					'min'        => 0,
					'max'        => 100,
					'step'       => 1,
					'refresh'    => false,
					'customizer' => 'gap',          // SASS variable's name to preview changes 'on fly'
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'slider',
				),
				'expand_content'                => array(
					'title'   => esc_html__( 'Expand content', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Expand the content width if the sidebar is hidden', 'rumble' ) ),
					'refresh' => false,
					'override'   => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'std'     => 1,
					'type'    => 'checkbox',
				),

				'general_widgets_info'          => array(
					'title' => esc_html__( 'Additional widgets', 'rumble' ),
					'desc'  => '',
					'type'  => RUMBLE_THEME_FREE ? 'hidden' : 'info',
				),
				'widgets_above_page'            => array(
					'title'    => esc_html__( 'Widgets at the top of the page', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select widgets to show at the top of the page (above content and sidebar)', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'std'      => 'hide',
					'options'  => array(),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'widgets_above_content'         => array(
					'title'    => esc_html__( 'Widgets above the content', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select widgets to show at the beginning of the content area', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'std'      => 'hide',
					'options'  => array(),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'widgets_below_content'         => array(
					'title'    => esc_html__( 'Widgets below the content', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select widgets to show at the ending of the content area', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'std'      => 'hide',
					'options'  => array(),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'widgets_below_page'            => array(
					'title'    => esc_html__( 'Widgets at the bottom of the page', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select widgets to show at the bottom of the page (below content and sidebar)', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'std'      => 'hide',
					'options'  => array(),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),

				'general_effects_info'          => array(
					'title' => esc_html__( 'Design & Effects', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'border_radius'                 => array(
					'title'      => esc_html__( 'Border radius', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Specify the border radius of the form fields and buttons in pixels', 'rumble' ) ),
					'std'        => 0,
					'min'        => 0,
					'max'        => 20,
					'step'       => 1,
					'refresh'    => false,
					'customizer' => 'rad',      // SASS name to preview changes 'on fly'
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'slider',
				),

				'general_misc_info'             => array(
					'title' => esc_html__( 'Miscellaneous', 'rumble' ),
					'desc'  => '',
					'type'  => RUMBLE_THEME_FREE ? 'hidden' : 'info',
				),
				'seo_snippets'                  => array(
					'title' => esc_html__( 'SEO snippets', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Add structured data markup to the single posts and pages', 'rumble' ) ),
					'std'   => 0,
					'type'  => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'privacy_text' => array(
					"title" => esc_html__("Text with Privacy Policy link", 'rumble'),
					"desc"  => wp_kses_data( __("Specify text with Privacy Policy link for the checkbox 'I agree ...'", 'rumble') ),
					"std"   => wp_kses( __( 'I agree that my submitted data is being collected and stored.', 'rumble'), 'rumble_kses_content' ),
					"type"  => "text"
				),



				// 'Header'
				//---------------------------------------------
				'header'                        => array(
					'title'    => esc_html__( 'Header', 'rumble' ),
					'desc'     => wp_kses_data( $msg_override ),
					'priority' => 30,
					'type'     => 'section',
				),

				'header_style_info'             => array(
					'title' => esc_html__( 'Header style', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'header_type'                   => array(
					'title'    => esc_html__( 'Header style', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Choose whether to use the default header or header Layouts (available only if the ThemeREX Addons is activated)', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'std'      => 'default',
					'options'  => rumble_get_list_header_footer_types(),
					'type'     => RUMBLE_THEME_FREE || ! rumble_exists_trx_addons() ? 'hidden' : 'switch',
				),
				'header_style'                  => array(
					'title'      => esc_html__( 'Select custom layout', 'rumble' ),
					'desc'       => wp_kses( __( 'Select custom header from Layouts Builder', 'rumble' ), 'rumble_kses_content' ),
					'override'   => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'dependency' => array(
						'header_type' => array( 'custom' ),
					),
					'std'        => RUMBLE_THEME_FREE ? 'header-custom-elementor-header-default' : 'header-custom-header-default',
					'options'    => array(),
					'type'       => 'select',
				),
				'header_position'               => array(
					'title'    => esc_html__( 'Header position', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select position to display the site header', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'std'      => 'default',
					'options'  => array(),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),
				'header_fullheight'             => array(
					'title'    => esc_html__( 'Header fullheight', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Enlarge header area to fill whole screen. Used only if header have a background image', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'std'      => 0,
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'header_wide'                   => array(
					'title'      => esc_html__( 'Header fullwidth', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Do you want to stretch the header widgets area to the entire window width?', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'dependency' => array(
						'header_type' => array( 'default' ),
					),
					'std'        => 1,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'header_zoom'                   => array(
					'title'   => esc_html__( 'Header zoom', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Zoom the header title. 1 - original size', 'rumble' ) ),
					'std'     => 1,
					'min'     => 0.3,
					'max'     => 2,
					'step'    => 0.1,
					'refresh' => false,
					'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'slider',
				),

				'header_widgets_info'           => array(
					'title' => esc_html__( 'Header widgets', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Here you can place a widget slider, advertising banners, etc.', 'rumble' ) ),
					'type'  => 'info',
				),
				'header_widgets'                => array(
					'title'    => esc_html__( 'Header widgets', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select set of widgets to show in the header on each page', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Header', 'rumble' ),
						'desc'    => wp_kses_data( __( 'Select set of widgets to show in the header on this page', 'rumble' ) ),
					),
					'std'      => 'hide',
					'options'  => array(),
					'type'     => 'select',
				),
				'header_columns'                => array(
					'title'      => esc_html__( 'Header columns', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select number columns to show widgets in the Header. If 0 - autodetect by the widgets count', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'dependency' => array(
						'header_widgets' => array( '^hide' ),
					),
					'std'        => 0,
					'options'    => rumble_get_list_range( 0, 6 ),
					'type'       => 'select',
				),

				'menu_info'                     => array(
					'title' => esc_html__( 'Main menu', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Select main menu style, position and other parameters', 'rumble' ) ),
					'type'  => RUMBLE_THEME_FREE ? 'hidden' : 'info',
				),
				'menu_style'                    => array(
					'title'    => esc_html__( 'Menu position', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select position of the main menu', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'std'      => 'top',
					'options'  => array(
						'top'   => esc_html__( 'Top', 'rumble' ),
					),
					'type'     => RUMBLE_THEME_FREE || ! rumble_exists_trx_addons() ? 'hidden' : 'switch',
				),
				'menu_side_stretch'             => array(
					'title'      => esc_html__( 'Stretch sidemenu', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Stretch sidemenu to window height (if menu items number >= 5)', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'dependency' => array(
						'menu_style' => array( 'left', 'right' ),
					),
					'std'        => 0,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'menu_side_icons'               => array(
					'title'      => esc_html__( 'Iconed sidemenu', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Get icons from anchors and display it in the sidemenu or mark sidemenu items with simple dots', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'dependency' => array(
						'menu_style' => array( 'left', 'right' ),
					),
					'std'        => 1,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'menu_mobile_fullscreen'        => array(
					'title' => esc_html__( 'Mobile menu fullscreen', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Display mobile and side menus on full screen (if checked) or slide narrow menu from the left or from the right side (if not checked)', 'rumble' ) ),
					'std'   => 1,
					'type'  => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),

				'header_image_info'             => array(
					'title' => esc_html__( 'Header image', 'rumble' ),
					'desc'  => '',
					'type'  => RUMBLE_THEME_FREE ? 'hidden' : 'info',
				),
				'header_image_override'         => array(
					'title'    => esc_html__( 'Header image override', 'rumble' ),
					'desc'     => wp_kses_data( __( "Allow override the header image with the page's/post's/product's/etc. featured image", 'rumble' ) ),
					'override' => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'std'      => 0,
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),

				'header_mobile_info'            => array(
					'title'      => esc_html__( 'Mobile header', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Configure the mobile version of the header', 'rumble' ) ),
					'priority'   => 500,
					'dependency' => array(
						'header_type' => array( 'default' ),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'info',
				),
				'header_mobile_enabled'         => array(
					'title'      => esc_html__( 'Enable the mobile header', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Use the mobile version of the header (if checked) or relayout the current header on mobile devices', 'rumble' ) ),
					'dependency' => array(
						'header_type' => array( 'default' ),
					),
					'std'        => 0,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'header_mobile_additional_info' => array(
					'title'      => esc_html__( 'Additional info', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Additional info to show at the top of the mobile header', 'rumble' ) ),
					'std'        => '',
					'dependency' => array(
						'header_type'           => array( 'default' ),
						'header_mobile_enabled' => array( 1 ),
					),
					'refresh'    => false,
					'teeny'      => false,
					'rows'       => 20,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'text_editor',
				),
				'header_mobile_hide_info'       => array(
					'title'      => esc_html__( 'Hide additional info', 'rumble' ),
					'std'        => 0,
					'dependency' => array(
						'header_type'           => array( 'default' ),
						'header_mobile_enabled' => array( 1 ),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'header_mobile_hide_logo'       => array(
					'title'      => esc_html__( 'Hide logo', 'rumble' ),
					'std'        => 0,
					'dependency' => array(
						'header_type'           => array( 'default' ),
						'header_mobile_enabled' => array( 1 ),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'header_mobile_hide_login'      => array(
					'title'      => esc_html__( 'Hide login/logout', 'rumble' ),
					'std'        => 0,
					'dependency' => array(
						'header_type'           => array( 'default' ),
						'header_mobile_enabled' => array( 1 ),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'header_mobile_hide_search'     => array(
					'title'      => esc_html__( 'Hide search', 'rumble' ),
					'std'        => 0,
					'dependency' => array(
						'header_type'           => array( 'default' ),
						'header_mobile_enabled' => array( 1 ),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'header_mobile_hide_cart'       => array(
					'title'      => esc_html__( 'Hide cart', 'rumble' ),
					'std'        => 0,
					'dependency' => array(
						'header_type'           => array( 'default' ),
						'header_mobile_enabled' => array( 1 ),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),



				// 'Footer'
				//---------------------------------------------
				'footer'                        => array(
					'title'    => esc_html__( 'Footer', 'rumble' ),
					'desc'     => wp_kses_data( $msg_override ),
					'priority' => 50,
					'type'     => 'section',
				),
				'footer_type'                   => array(
					'title'    => esc_html__( 'Footer style', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Choose whether to use the default footer or footer Layouts (available only if the ThemeREX Addons is activated)', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Footer', 'rumble' ),
					),
					'std'      => 'default',
					'options'  => rumble_get_list_header_footer_types(),
					'type'     => RUMBLE_THEME_FREE || ! rumble_exists_trx_addons() ? 'hidden' : 'switch',
				),
				'footer_style'                  => array(
					'title'      => esc_html__( 'Select custom layout', 'rumble' ),
					'desc'       => wp_kses( __( 'Select custom footer from Layouts Builder', 'rumble' ), 'rumble_kses_content' ),
					'override'   => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Footer', 'rumble' ),
					),
					'dependency' => array(
						'footer_type' => array( 'custom' ),
					),
					'std'        => RUMBLE_THEME_FREE ? 'default-footer-elementor' : 'default-footer-elementor',
					'options'    => array(),
					'type'       => 'select',
				),
				'footer_widgets'                => array(
					'title'      => esc_html__( 'Footer widgets', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select set of widgets to show in the footer', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Footer', 'rumble' ),
					),
					'dependency' => array(
						'footer_type' => array( 'default' ),
					),
					'std'        => 'footer_widgets',
					'options'    => array(),
					'type'       => 'select',
				),
				'footer_columns'                => array(
					'title'      => esc_html__( 'Footer columns', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select number columns to show widgets in the footer. If 0 - autodetect by the widgets count', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Footer', 'rumble' ),
					),
					'dependency' => array(
						'footer_type'    => array( 'default' ),
						'footer_widgets' => array( '^hide' ),
					),
					'std'        => 0,
					'options'    => rumble_get_list_range( 0, 6 ),
					'type'       => 'select',
				),
				'footer_wide'                   => array(
					'title'      => esc_html__( 'Footer fullwidth', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Do you want to stretch the footer to the entire window width?', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page,post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Footer', 'rumble' ),
					),
					'dependency' => array(
						'footer_type' => array( 'default' ),
					),
					'std'        => 0,
					'type'       => 'checkbox',
				),
				'logo_in_footer'                => array(
					'title'      => esc_html__( 'Show logo', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Show logo in the footer', 'rumble' ) ),
					'refresh'    => false,
					'dependency' => array(
						'footer_type' => array( 'default' ),
					),
					'std'        => 0,
					'type'       => 'checkbox',
				),
				'logo_footer'                   => array(
					'title'      => esc_html__( 'Logo for footer', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select or upload site logo to display it in the footer', 'rumble' ) ),
					'dependency' => array(
						'footer_type'    => array( 'default' ),
						'logo_in_footer' => array( 1 ),
					),
					'std'        => '',
					'type'       => 'image',
				),
				'logo_footer_retina'            => array(
					'title'      => esc_html__( 'Logo for footer (Retina)', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select or upload logo for the footer area used on Retina displays (if empty - use default logo from the field above)', 'rumble' ) ),
					'dependency' => array(
						'footer_type'         => array( 'default' ),
						'logo_in_footer'      => array( 1 ),
						'logo_retina_enabled' => array( 1 ),
					),
					'std'        => '',
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'image',
				),
				'socials_in_footer'             => array(
					'title'      => esc_html__( 'Show social icons', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Show social icons in the footer (under logo or footer widgets)', 'rumble' ) ),
					'dependency' => array(
						'footer_type' => array( 'default' ),
					),
					'std'        => 0,
					'type'       => ! rumble_exists_trx_addons() ? 'hidden' : 'checkbox',
				),
				'copyright'                     => array(
					'title'      => esc_html__( 'Copyright', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Copyright text in the footer. Use {Y} to insert current year and press "Enter" to create a new line', 'rumble' ) ),
					'translate'  => true,
					'std'        => esc_html__( 'AncoraThemes &copy; {Y}. All rights reserved.', 'rumble' ),
					'dependency' => array(
						'footer_type' => array( 'default' ),
					),
					'refresh'    => false,
					'type'       => 'textarea',
				),



				// 'Mobile version'
				//---------------------------------------------
				'mobile'                        => array(
					'title'    => esc_html__( 'Mobile', 'rumble' ),
					'desc'     => wp_kses_data( $msg_override ),
					'priority' => 55,
					'type'     => 'section',
				),

				'mobile_header_info'            => array(
					'title' => esc_html__( 'Header on the mobile device', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'header_type_mobile'            => array(
					'title'    => esc_html__( 'Header style', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Choose whether to use on mobile devices: the default header or header Layouts (available only if the ThemeREX Addons is activated)', 'rumble' ) ),
					'std'      => 'inherit',
					'options'  => rumble_get_list_header_footer_types( true ),
					'type'     => RUMBLE_THEME_FREE || ! rumble_exists_trx_addons() ? 'hidden' : 'switch',
				),
				'header_style_mobile'           => array(
					'title'      => esc_html__( 'Select custom layout', 'rumble' ),
					'desc'       => wp_kses( __( 'Select custom header from Layouts Builder', 'rumble' ), 'rumble_kses_content' ),
					'dependency' => array(
						'header_type_mobile' => array( 'custom' ),
					),
					'std'        => 'inherit',
					'options'    => array(),
					'type'       => 'select',
				),
				'header_position_mobile'        => array(
					'title'    => esc_html__( 'Header position', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select position to display the site header', 'rumble' ) ),
					'std'      => 'inherit',
					'options'  => array(),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),

				'mobile_sidebar_info'           => array(
					'title' => esc_html__( 'Sidebar on the mobile device', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'sidebar_position_mobile'       => array(
					'title'    => esc_html__( 'Sidebar position on mobile', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select position to show sidebar on mobile devices - above or below the content', 'rumble' ) ),
					'std'      => 'inherit',
					'options'  => array(),
					'type'     => 'switch',
				),
				'sidebar_widgets_mobile'        => array(
					'title'      => esc_html__( 'Sidebar widgets', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select default widgets to show in the sidebar on mobile devices', 'rumble' ) ),
					'dependency' => array(
						'sidebar_position_mobile' => array( '^hide' ),
					),
					'std'        => 'sidebar_widgets',
					'options'    => array(),
					'type'       => 'select',
				),
				'expand_content_mobile'         => array(
					'title'   => esc_html__( 'Expand content', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Expand the content width if the sidebar is hidden on mobile devices', 'rumble' ) ),
					'refresh' => false,
					'dependency' => array(
						'sidebar_position_mobile' => array( 'hide', 'inherit' ),
					),
					'std'     => 'inherit',
					'options'  => rumble_get_list_checkbox_values( true ),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),

				'mobile_footer_info'           => array(
					'title' => esc_html__( 'Footer on the mobile device', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'footer_type_mobile'           => array(
					'title'    => esc_html__( 'Footer style', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Choose whether to use on mobile devices: the default footer or footer Layouts (available only if the ThemeREX Addons is activated)', 'rumble' ) ),
					'std'      => 'inherit',
					'options'  => rumble_get_list_header_footer_types(),
					'type'     => RUMBLE_THEME_FREE || ! rumble_exists_trx_addons() ? 'hidden' : 'switch',
				),
				'footer_style_mobile'          => array(
					'title'      => esc_html__( 'Select custom layout', 'rumble' ),
					'desc'       => wp_kses( __( 'Select custom footer from Layouts Builder', 'rumble' ), 'rumble_kses_content' ),
					'dependency' => array(
						'footer_type_mobile' => array( 'custom' ),
					),
					'std'        => 'inherit',
					'options'    => array(),
					'type'       => 'select',
				),
				'footer_widgets_mobile'        => array(
					'title'      => esc_html__( 'Footer widgets', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select set of widgets to show in the footer', 'rumble' ) ),
					'dependency' => array(
						'footer_type_mobile' => array( 'default' ),
					),
					'std'        => 'footer_widgets',
					'options'    => array(),
					'type'       => 'select',
				),
				'footer_columns_mobile'        => array(
					'title'      => esc_html__( 'Footer columns', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select number columns to show widgets in the footer. If 0 - autodetect by the widgets count', 'rumble' ) ),
					'dependency' => array(
						'footer_type_mobile'    => array( 'default' ),
						'footer_widgets_mobile' => array( '^hide' ),
					),
					'std'        => 0,
					'options'    => rumble_get_list_range( 0, 6 ),
					'type'       => 'select',
				),



				// 'Blog'
				//---------------------------------------------
				'blog'                          => array(
					'title'    => esc_html__( 'Blog', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Options of the the blog archive', 'rumble' ) ),
					'priority' => 70,
					'type'     => 'panel',
				),


				// Blog - Posts page
				//---------------------------------------------
				'blog_general'                  => array(
					'title' => esc_html__( 'Posts page', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Style and components of the blog archive', 'rumble' ) ),
					'type'  => 'section',
				),
				'blog_general_info'             => array(
					'title'  => esc_html__( 'Posts page settings', 'rumble' ),
					'desc'   => '',
					'qsetup' => esc_html__( 'General', 'rumble' ),
					'type'   => 'info',
				),
				'blog_style'                    => array(
					'title'      => esc_html__( 'Blog style', 'rumble' ),
					'desc'       => '',
					'override'   => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'compare' => 'or',
						'#page_template' => array( 'blog.php' ),
						'.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					'std'        => 'excerpt',
					'qsetup'     => esc_html__( 'General', 'rumble' ),
					'options'    => array(),
					'type'       => 'select',
				),
				'first_post_large'              => array(
					'title'      => esc_html__( 'First post large', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Make your first post stand out by making it bigger', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'compare' => 'or',
						'#page_template' => array( 'blog.php' ),
						'.editor-page-attributes__template select' => array( 'blog.php' ),
						'blog_style' => array( 'classic', 'masonry' ),
					),
					'std'        => 0,
					'type'       => 'checkbox',
				),
				'blog_content'                  => array(
					'title'      => esc_html__( 'Posts content', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Display either post excerpts or the full post content', 'rumble' ) ),
					'std'        => 'excerpt',
					'dependency' => array(
						'blog_style' => array( 'excerpt' ),
					),
					'options'    => array(
						'excerpt'  => esc_html__( 'Excerpt', 'rumble' ),
						'fullpost' => esc_html__( 'Full post', 'rumble' ),
					),
					'type'       => 'switch',
				),
				'excerpt_length'                => array(
					'title'      => esc_html__( 'Excerpt length', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Length (in words) to generate excerpt from the post content. Attention! If the post excerpt is explicitly specified - it appears unchanged', 'rumble' ) ),
					'dependency' => array(
						'blog_style'   => array( 'excerpt' ),
						'blog_content' => array( 'excerpt' ),
					),
					'std'        => 45,
					'type'       => 'text',
				),
				'blog_columns'                  => array(
					'title'   => esc_html__( 'Blog columns', 'rumble' ),
					'desc'    => wp_kses_data( __( 'How many columns should be used in the blog archive (from 2 to 4)?', 'rumble' ) ),
					'std'     => 2,
					'options' => rumble_get_list_range( 2, 4 ),
					'type'    => 'hidden',      // This options is available and must be overriden only for some modes (for example, 'shop')
				),
				'post_type'                     => array(
					'title'      => esc_html__( 'Post type', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select post type to show in the blog archive', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'compare' => 'or',
						'#page_template' => array( 'blog.php' ),
						'.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					'linked'     => 'parent_cat',
					'refresh'    => false,
					'hidden'     => true,
					'std'        => 'post',
					'options'    => array(),
					'type'       => 'select',
				),
				'parent_cat'                    => array(
					'title'      => esc_html__( 'Category to show', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select category to show in the blog archive', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'compare' => 'or',
						'#page_template' => array( 'blog.php' ),
						'.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					'refresh'    => false,
					'hidden'     => true,
					'std'        => '0',
					'options'    => array(),
					'type'       => 'select',
				),
				'posts_per_page'                => array(
					'title'      => esc_html__( 'Posts per page', 'rumble' ),
					'desc'       => wp_kses_data( __( 'How many posts will be displayed on this page', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'compare' => 'or',
						'#page_template' => array( 'blog.php' ),
						'.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					'hidden'     => true,
					'std'        => '',
					'type'       => 'text',
				),
				'blog_pagination'               => array(
					'title'      => esc_html__( 'Pagination style', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Show Older/Newest posts or Page numbers below the posts list', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'std'        => 'pages',
					'qsetup'     => esc_html__( 'General', 'rumble' ),
					'dependency' => array(
						'compare' => 'or',
						'#page_template' => array( 'blog.php' ),
						'.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					'options'    => array(
						'pages'    => esc_html__( 'Page numbers', 'rumble' ),
						'links'    => esc_html__( 'Older/Newest', 'rumble' ),
						'more'     => esc_html__( 'Load more', 'rumble' ),
						'infinite' => esc_html__( 'Infinite scroll', 'rumble' ),
					),
					'type'       => 'select',
				),
				'blog_animation'                => array(
					'title'      => esc_html__( 'Animation for the posts', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select animation to show posts in the blog. Attention! Do not use any animation on pages with the "wheel to the anchor" behaviour (like a "Chess 2 columns")!', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'compare' => 'or',
						'#page_template' => array( 'blog.php' ),
						'.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					'std'        => 'none',
					'options'    => array(),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'show_filters'                  => array(
					'title'      => esc_html__( 'Show filters', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Show categories as tabs to filter posts', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'compare' => 'or',
						'#page_template' => array( 'blog.php' ),
						'.editor-page-attributes__template select' => array( 'blog.php' ),
						'blog_style'     => array( 'portfolio', 'gallery' ),
					),
					'hidden'     => true,
					'std'        => 0,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),

				'blog_header_info'              => array(
					'title' => esc_html__( 'Header', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'header_type_blog'              => array(
					'title'    => esc_html__( 'Header style', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Choose whether to use the default header or header Layouts (available only if the ThemeREX Addons is activated)', 'rumble' ) ),
					'std'      => 'inherit',
					'options'  => rumble_get_list_header_footer_types( true ),
					'type'     => RUMBLE_THEME_FREE || ! rumble_exists_trx_addons() ? 'hidden' : 'switch',
				),
				'header_style_blog'             => array(
					'title'      => esc_html__( 'Select custom layout', 'rumble' ),
					'desc'       => wp_kses( __( 'Select custom header from Layouts Builder', 'rumble' ), 'rumble_kses_content' ),
					'dependency' => array(
						'header_type_blog' => array( 'custom' ),
					),
					'std'        => RUMBLE_THEME_FREE ? 'header-custom-elementor-header-default' : 'header-custom-header-default',
					'options'    => array(),
					'type'       => 'select',
				),
				'header_position_blog'          => array(
					'title'    => esc_html__( 'Header position', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select position to display the site header', 'rumble' ) ),
					'std'      => 'inherit',
					'options'  => array(),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),
				'header_fullheight_blog'        => array(
					'title'    => esc_html__( 'Header fullheight', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Enlarge header area to fill whole screen. Used only if header have a background image', 'rumble' ) ),
					'std'      => 'inherit',
					'options'  => rumble_get_list_checkbox_values( true ),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),
				'header_wide_blog'              => array(
					'title'      => esc_html__( 'Header fullwidth', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Do you want to stretch the header widgets area to the entire window width?', 'rumble' ) ),
					'dependency' => array(
						'header_type_blog' => array( 'default' ),
					),
					'std'      => 'inherit',
					'options'  => rumble_get_list_checkbox_values( true ),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),

				'blog_sidebar_info'             => array(
					'title' => esc_html__( 'Sidebar', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'sidebar_position_blog'         => array(
					'title'   => esc_html__( 'Sidebar position', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Select position to show sidebar', 'rumble' ) ),
					'std'     => 'inherit',
					'options' => array(),
					'qsetup'     => esc_html__( 'General', 'rumble' ),
					'type'    => 'switch',
				),
				'sidebar_position_ss_blog'  => array(
					'title'    => esc_html__( 'Sidebar position on the small screen', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select position to move sidebar on the small screen - above or below the content', 'rumble' ) ),
					'dependency' => array(
						'sidebar_position_blog' => array( '^hide' ),
					),
					'std'      => 'inherit',
					'qsetup'   => esc_html__( 'General', 'rumble' ),
					'options'  => array(),
					'type'     => 'switch',
				),
				'sidebar_widgets_blog'          => array(
					'title'      => esc_html__( 'Sidebar widgets', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select default widgets to show in the sidebar', 'rumble' ) ),
					'dependency' => array(
						'sidebar_position_blog' => array( '^hide' ),
					),
					'std'        => 'sidebar_widgets',
					'options'    => array(),
					'qsetup'     => esc_html__( 'General', 'rumble' ),
					'type'       => 'select',
				),
				'expand_content_blog'           => array(
					'title'   => esc_html__( 'Expand content', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Expand the content width if the sidebar is hidden', 'rumble' ) ),
					'refresh' => false,
					'std'     => 'inherit',
					'options'  => rumble_get_list_checkbox_values( true ),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),

				'blog_widgets_info'             => array(
					'title' => esc_html__( 'Additional widgets', 'rumble' ),
					'desc'  => '',
					'type'  => RUMBLE_THEME_FREE ? 'hidden' : 'info',
				),
				'widgets_above_page_blog'       => array(
					'title'   => esc_html__( 'Widgets at the top of the page', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Select widgets to show at the top of the page (above content and sidebar)', 'rumble' ) ),
					'std'     => 'hide',
					'options' => array(),
					'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'widgets_above_content_blog'    => array(
					'title'   => esc_html__( 'Widgets above the content', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Select widgets to show at the beginning of the content area', 'rumble' ) ),
					'std'     => 'hide',
					'options' => array(),
					'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'widgets_below_content_blog'    => array(
					'title'   => esc_html__( 'Widgets below the content', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Select widgets to show at the ending of the content area', 'rumble' ) ),
					'std'     => 'hide',
					'options' => array(),
					'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'widgets_below_page_blog'       => array(
					'title'   => esc_html__( 'Widgets at the bottom of the page', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Select widgets to show at the bottom of the page (below content and sidebar)', 'rumble' ) ),
					'std'     => 'hide',
					'options' => array(),
					'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),

				'blog_advanced_info'            => array(
					'title' => esc_html__( 'Advanced settings', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'no_image'                      => array(
					'title' => esc_html__( 'Image placeholder', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Select or upload an image used as placeholder for posts without a featured image', 'rumble' ) ),
					'std'   => '',
					'type'  => 'image',
				),
				'time_diff_before'              => array(
					'title' => esc_html__( 'Easy Readable Date Format', 'rumble' ),
					'desc'  => wp_kses_data( __( "For how many days to show the easy-readable date format (e.g. '3 days ago') instead of the standard publication date", 'rumble' ) ),
					'std'   => 5,
					'type'  => 'text',
				),
				'sticky_style'                  => array(
					'title'   => esc_html__( 'Sticky posts style', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Select style of the sticky posts output', 'rumble' ) ),
					'std'     => 'inherit',
					'options' => array(
						'inherit' => esc_html__( 'Decorated posts', 'rumble' ),
						'columns' => esc_html__( 'Mini-cards', 'rumble' ),
					),
					'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'meta_parts'                    => array(
					'title'      => esc_html__( 'Post meta', 'rumble' ),
					'desc'       => wp_kses_data( __( "If your blog page is created using the 'Blog archive' page template, set up the 'Post Meta' settings in the 'Theme Options' section of that page. Post counters and Share Links are available only if plugin ThemeREX Addons is active", 'rumble' ) )
								. '<br>'
								. wp_kses_data( __( '<b>Tip:</b> Drag items to change their order.', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'compare' => 'or',
						'#page_template' => array( 'blog.php' ),
						'.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					'dir'        => 'vertical',
					'sortable'   => true,
					'std'        => 'categories=1|date=1|views=0|likes=0|comments=0|author=0|share=0|edit=0',
					'options'    => rumble_get_list_meta_parts(),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checklist',
				),


				// Blog - Single posts
				//---------------------------------------------
				'blog_single'                   => array(
					'title' => esc_html__( 'Single posts', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Settings of the single post', 'rumble' ) ),
					'type'  => 'section',
				),

				'blog_single_header_info'       => array(
					'title' => esc_html__( 'Header', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'header_type_single'            => array(
					'title'    => esc_html__( 'Header style', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Choose whether to use the default header or header Layouts (available only if the ThemeREX Addons is activated)', 'rumble' ) ),
					'std'      => 'inherit',
					'options'  => rumble_get_list_header_footer_types( true ),
					'type'     => RUMBLE_THEME_FREE || ! rumble_exists_trx_addons() ? 'hidden' : 'switch',
				),
				'header_style_single'           => array(
					'title'      => esc_html__( 'Select custom layout', 'rumble' ),
					'desc'       => wp_kses( __( 'Select custom header from Layouts Builder', 'rumble' ), 'rumble_kses_content' ),
					'dependency' => array(
						'header_type_single' => array( 'custom' ),
					),
					'std'        => RUMBLE_THEME_FREE ? 'header-custom-elementor-header-default' : 'header-custom-header-default',
					'options'    => array(),
					'type'       => 'select',
				),
				'header_position_single'        => array(
					'title'    => esc_html__( 'Header position', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select position to display the site header', 'rumble' ) ),
					'std'      => 'inherit',
					'options'  => array(),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),
				'header_fullheight_single'      => array(
					'title'    => esc_html__( 'Header fullheight', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Enlarge header area to fill whole screen. Used only if header have a background image', 'rumble' ) ),
					'std'      => 'inherit',
					'options'  => rumble_get_list_checkbox_values( true ),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),
				'header_wide_single'            => array(
					'title'      => esc_html__( 'Header fullwidth', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Do you want to stretch the header widgets area to the entire window width?', 'rumble' ) ),
					'dependency' => array(
						'header_type_single' => array( 'default' ),
					),
					'std'      => 'inherit',
					'options'  => rumble_get_list_checkbox_values( true ),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),

				'blog_single_sidebar_info'      => array(
					'title' => esc_html__( 'Sidebar', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'sidebar_position_single'       => array(
					'title'   => esc_html__( 'Sidebar position', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Select position to show sidebar on the single posts', 'rumble' ) ),
					'std'     => 'inherit',
					'override'   => array(
						'mode'    => 'post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'options' => array(),
					'type'    => 'switch',
				),
				'sidebar_position_ss_single'=> array(
					'title'    => esc_html__( 'Sidebar position on the small screen', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select position to move sidebar on the single posts on the small screen - above or below the content', 'rumble' ) ),
					'override' => array(
						'mode'    => 'post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'dependency' => array(
						'sidebar_position_single' => array( '^hide' ),
					),
					'std'      => 'below',
					'options'  => array(),
					'type'     => 'switch',
				),
				'sidebar_widgets_single'        => array(
					'title'      => esc_html__( 'Sidebar widgets', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select default widgets to show in the sidebar on the single posts', 'rumble' ) ),
					'override'   => array(
						'mode'    => 'post,product,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Widgets', 'rumble' ),
					),
					'dependency' => array(
						'sidebar_position_single' => array( '^hide' ),
					),
					'std'        => 'sidebar_widgets',
					'options'    => array(),
					'type'       => 'select',
				),
				'expand_content_single'           => array(
					'title'   => esc_html__( 'Expand content', 'rumble' ),
					'desc'    => wp_kses_data( __( 'Expand the content width on the single posts if the sidebar is hidden', 'rumble' ) ),
					'refresh' => false,
					'std'     => 'inherit',
					'options'  => rumble_get_list_checkbox_values( true ),
					'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),

				'blog_single_title_info'      => array(
					'title' => esc_html__( 'Featured image and title', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'hide_featured_on_single'       => array(
					'title'    => esc_html__( 'Hide featured image on the single post', 'rumble' ),
					'desc'     => wp_kses_data( __( "Hide featured image on the single post's pages", 'rumble' ) ),
					'override' => array(
						'mode'    => 'page,post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'std'      => 0,
					'type'     => 'checkbox',
				),
				'post_thumbnail_type'      => array(
					'title'      => esc_html__( 'Type of post thumbnail', 'rumble' ),
					'desc'       => wp_kses_data( __( "Select type of post thumbnail on the single post's pages", 'rumble' ) ),
					'override'   => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'hide_featured_on_single' => array( 'is_empty', 0 ),
					),
					'std'        => 'default',
					'options'    => array(
						'fullwidth'   => esc_html__( 'Fullwidth', 'rumble' ),
						'boxed'       => esc_html__( 'Boxed', 'rumble' ),
						'default'     => esc_html__( 'Default', 'rumble' ),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'post_header_position'          => array(
					'title'      => esc_html__( 'Post header position', 'rumble' ),
					'desc'       => wp_kses_data( __( "Select post header position on the single post's pages", 'rumble' ) ),
					'override'   => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'hide_featured_on_single' => array( 'is_empty', 0 )
					),
					'std'        => 'under',
					'options'    => array(
						'above'      => esc_html__( 'Above the post thumbnail', 'rumble' ),
						'under'      => esc_html__( 'Under the post thumbnail', 'rumble' ),
						'on_thumb'   => esc_html__( 'On the post thumbnail', 'rumble' ),
						'default'    => esc_html__( 'Default', 'rumble' ),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'post_header_align'             => array(
					'title'      => esc_html__( 'Align of the post header', 'rumble' ),
					'override'   => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'post_header_position' => array( 'on_thumb' ),
					),
					'std'        => 'mc',
					'options'    => array(
						'ts' => esc_html__('Top Stick Out', 'rumble'),
						'tl' => esc_html__('Top Left', 'rumble'),
						'tc' => esc_html__('Top Center', 'rumble'),
						'tr' => esc_html__('Top Right', 'rumble'),
						'ml' => esc_html__('Middle Left', 'rumble'),
						'mc' => esc_html__('Middle Center', 'rumble'),
						'mr' => esc_html__('Middle Right', 'rumble'),
						'bl' => esc_html__('Bottom Left', 'rumble'),
						'bc' => esc_html__('Bottom Center', 'rumble'),
						'br' => esc_html__('Bottom Right', 'rumble'),
						'bs' => esc_html__('Bottom Stick Out', 'rumble'),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'post_subtitle'                 => array(
					'title' => esc_html__( 'Post subtitle', 'rumble' ),
					'desc'  => wp_kses_data( __( "Specify post subtitle to display it under the post title.", 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'std'   => '',
					'hidden' => true,
					'type'  => 'text',
				),
				'show_post_meta'                => array(
					'title' => esc_html__( 'Show post meta', 'rumble' ),
					'desc'  => wp_kses_data( __( "Display block with post's meta: date, categories, counters, etc.", 'rumble' ) ),
					'std'   => 1,
					'type'  => 'checkbox',
				),
				'meta_parts_single'             => array(
					'title'      => esc_html__( 'Post meta', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Meta parts for single posts. Post counters and Share Links are available only if plugin ThemeREX Addons is active', 'rumble' ) )
								. '<br>'
								. wp_kses_data( __( '<b>Tip:</b> Drag items to change their order.', 'rumble' ) ),
					'dependency' => array(
						'show_post_meta' => array( 1 ),
					),
					'dir'        => 'vertical',
					'sortable'   => true,
					'std'        => 'categories=1|date=1|views=0|likes=0|comments=0|author=0|share=0|edit=0',
					'options'    => rumble_get_list_meta_parts(),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checklist',
				),
				'show_share_links'              => array(
					'title' => esc_html__( 'Show share links', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Display share links on the single post', 'rumble' ) ),
					'std'   => 1,
					'type'  => ! rumble_exists_trx_addons() ? 'hidden' : 'checkbox',
				),
				'show_author_info'              => array(
					'title' => esc_html__( 'Show author info', 'rumble' ),
					'desc'  => wp_kses_data( __( "Display block with information about post's author", 'rumble' ) ),
					'std'   => 1,
					'type'  => 'checkbox',
				),

				'blog_single_related_info'      => array(
					'title' => esc_html__( 'Related posts', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'show_related_posts'            => array(
					'title'    => esc_html__( 'Show related posts', 'rumble' ),
					'desc'     => wp_kses_data( __( "Show section 'Related posts' on the single post's pages", 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'std'      => 1,
					'type'     => 'checkbox',
				),
				'related_style'                 => array(
					'title'      => esc_html__( 'Related posts style', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select style of the related posts output', 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'show_related_posts' => array( 1 ),
					),
					'std'        => 'wide',
					'options'    => array(
						'modern'  => esc_html__( 'Modern', 'rumble' ),
						'classic' => esc_html__( 'Classic', 'rumble' ),
						'wide'    => esc_html__( 'Wide', 'rumble' ),
						'list'    => esc_html__( 'List', 'rumble' ),
						'short'   => esc_html__( 'Short', 'rumble' ),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),
				'related_position'              => array(
					'title'      => esc_html__( 'Related posts position', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Select position to display the related posts', 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'show_related_posts' => array( 1 ),
					),
					'std'        => 'below_content',
					'options'    => array (
						'inside'        => esc_html__( 'Inside the content (fullwidth)', 'rumble' ),
						'inside_left'   => esc_html__( 'At left side of the content', 'rumble' ),
						'inside_right'  => esc_html__( 'At right side of the content', 'rumble' ),
						'below_content' => esc_html__( 'After the content', 'rumble' ),
						'below_page'    => esc_html__( 'After the content & sidebar', 'rumble' ),
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'related_position_inside'       => array(
					'title'      => esc_html__( 'Before # paragraph', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Before what paragraph should related posts appear? If 0 - randomly.', 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'show_related_posts' => array( 1 ),
						'related_position' => array( 'inside', 'inside_left', 'inside_right' ),
					),
					'std'        => 3,
					'options'    => rumble_get_list_range( 0, 9 ),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'related_posts'                 => array(
					'title'      => esc_html__( 'Related posts', 'rumble' ),
					'desc'       => wp_kses_data( __( 'How many related posts should be displayed in the single post? If 0 - no related posts are shown.', 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'show_related_posts' => array( 1 ),
					),
					'std'        => 3,
					'min'        => 1,
					'max'        => 9,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'slider',
				),
				'related_columns'               => array(
					'title'      => esc_html__( 'Related columns', 'rumble' ),
					'desc'       => wp_kses_data( __( 'How many columns should be used to output related posts in the single page?', 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'show_related_posts' => array( 1 ),
						'related_position' => array( 'inside', 'below_content', 'below_page' ),
					),
					'std'        => 1,
					'options'    => rumble_get_list_range( 1, 6 ),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),
				'related_slider'                => array(
					'title'      => esc_html__( 'Use slider layout', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Use slider layout in case related posts count is more than columns count', 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'show_related_posts' => array( 1 ),
					),
					'std'        => 0,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'related_slider_controls'       => array(
					'title'      => esc_html__( 'Slider controls', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Show arrows in the slider', 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'show_related_posts' => array( 1 ),
						'related_slider' => array( 1 ),
					),
					'std'        => 'none',
					'options'    => array(
						'none'    => esc_html__('None', 'rumble'),
						'side'    => esc_html__('Side', 'rumble'),
						'outside' => esc_html__('Outside', 'rumble'),
						'top'     => esc_html__('Top', 'rumble'),
						'bottom'  => esc_html__('Bottom', 'rumble')
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'select',
				),
				'related_slider_pagination'       => array(
					'title'      => esc_html__( 'Slider pagination', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Show bullets after the slider', 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'show_related_posts' => array( 1 ),
						'related_slider' => array( 1 ),
					),
					'std'        => 'bottom',
					'options'    => array(
						'none'    => esc_html__('None', 'rumble'),
						'bottom'  => esc_html__('Bottom', 'rumble')
					),
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),
				'related_slider_space'          => array(
					'title'      => esc_html__( 'Space', 'rumble' ),
					'desc'       => wp_kses_data( __( 'Space between slides', 'rumble' ) ),
					'override' => array(
						'mode'    => 'post',
						'section' => esc_html__( 'Content', 'rumble' ),
					),
					'dependency' => array(
						'show_related_posts' => array( 1 ),
						'related_slider' => array( 1 ),
					),
					'std'        => 30,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'text',
				),
				'posts_navigation_info'      => array(
					'title' => esc_html__( 'Posts navigation', 'rumble' ),
					'desc'  => '',
					'type'  => 'info',
				),
				'posts_navigation'           => array(
					'title'   => esc_html__( 'Show posts navigation', 'rumble' ),
					'desc'    => wp_kses_data( __( "Show posts navigation on the single post's pages", 'rumble' ) ),
					'std'     => 'none',
					'options' => array(
						'none'   => esc_html__('None', 'rumble'),
						'links'  => esc_html__('Prev/Next links', 'rumble'),
						'scroll' => esc_html__('Infinite scroll', 'rumble')
					),
					'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
				),
				'posts_navigation_fixed'     => array(
					'title'      => esc_html__( 'Fixed posts navigation', 'rumble' ),
					'desc'       => wp_kses_data( __( "Make posts navigation fixed position. Display it when the content of the article is inside the window.", 'rumble' ) ),
					'dependency' => array(
						'posts_navigation' => array( 'links' ),
					),
					'std'        => 0,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'posts_navigation_scroll_hide_author'  => array(
					'title'      => esc_html__( 'Hide author bio', 'rumble' ),
					'desc'       => wp_kses_data( __( "Hide author bio after post content when infinite scroll is used.", 'rumble' ) ),
					'dependency' => array(
						'posts_navigation' => array( 'scroll' ),
					),
					'std'        => 0,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'posts_navigation_scroll_hide_related'  => array(
					'title'      => esc_html__( 'Hide related posts', 'rumble' ),
					'desc'       => wp_kses_data( __( "Hide related posts after post content when infinite scroll is used.", 'rumble' ) ),
					'dependency' => array(
						'posts_navigation' => array( 'scroll' ),
					),
					'std'        => 0,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),
				'posts_navigation_scroll_hide_comments' => array(
					'title'      => esc_html__( 'Hide comments', 'rumble' ),
					'desc'       => wp_kses_data( __( "Hide comments after post content when infinite scroll is used.", 'rumble' ) ),
					'dependency' => array(
						'posts_navigation' => array( 'scroll' ),
					),
					'std'        => 1,
					'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'checkbox',
				),


				// 'Colors'
				//---------------------------------------------
				'panel_colors'                  => array(
					'title'    => esc_html__( 'Colors', 'rumble' ),
					'desc'     => '',
					'priority' => 300,
					'type'     => 'section',
				),

				'color_schemes_info'            => array(
					'title'  => esc_html__( 'Color schemes', 'rumble' ),
					'desc'   => wp_kses_data( __( 'Color schemes for various parts of the site. "Inherit" means that this block is used the Site color scheme (the first parameter)', 'rumble' ) ),
					'hidden' => $hide_schemes,
					'type'   => 'info',
				),
				'color_scheme'                  => array(
					'title'    => esc_html__( 'Site Color Scheme', 'rumble' ),
					'desc'     => '',
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Colors', 'rumble' ),
					),
					'std'      => 'default',
					'options'  => array(),
					'refresh'  => false,
					'type'     => $hide_schemes ? 'hidden' : 'switch',
				),
				'header_scheme'                 => array(
					'title'    => esc_html__( 'Header Color Scheme', 'rumble' ),
					'desc'     => '',
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Colors', 'rumble' ),
					),
					'std'      => 'inherit',
					'options'  => array(),
					'refresh'  => false,
					'type'     => $hide_schemes ? 'hidden' : 'switch',
				),
				'sidebar_scheme'                => array(
					'title'    => esc_html__( 'Sidebar Color Scheme', 'rumble' ),
					'desc'     => '',
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Colors', 'rumble' ),
					),
					'std'      => 'inherit',
					'options'  => array(),
					'refresh'  => false,
					'type'     => $hide_schemes ? 'hidden' : 'switch',
				),
				'footer_scheme'                 => array(
					'title'    => esc_html__( 'Footer Color Scheme', 'rumble' ),
					'desc'     => '',
					'override' => array(
						'mode'    => 'page,cpt_team,cpt_services,cpt_dishes,cpt_competitions,cpt_rounds,cpt_matches,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
						'section' => esc_html__( 'Colors', 'rumble' ),
					),
					'std'      => 'inherit',
					'options'  => array(),
					'refresh'  => false,
					'type'     => $hide_schemes ? 'hidden' : 'switch',
				),

				'color_scheme_editor_info'      => array(
					'title' => esc_html__( 'Color scheme editor', 'rumble' ),
					'desc'  => wp_kses_data( __( 'Select color scheme to modify. Attention! Only those sections in the site will be changed which this scheme was assigned to', 'rumble' ) ),
					'type'  => 'info',
				),
				'scheme_storage'                => array(
					'title'       => esc_html__( 'Color scheme editor', 'rumble' ),
					'desc'        => '',
					'std'         => '$rumble_get_scheme_storage',
					'refresh'     => false,
					'colorpicker' => 'tiny',
					'type'        => 'scheme_editor',
				),

				// Internal options.
				// Attention! Don't change any options in the section below!
				// Use huge priority to call render this elements after all options!
				'reset_options'                 => array(
					'title'    => '',
					'desc'     => '',
					'std'      => '0',
					'priority' => 10000,
					'type'     => 'hidden',
				),

				'last_option'                   => array(     // Need to manually call action to include Tiny MCE scripts
					'title' => '',
					'desc'  => '',
					'std'   => 1,
					'type'  => 'hidden',
				),

			)
		);



		// Prepare panel 'Fonts'
		// -------------------------------------------------------------
		$fonts = array(

			// 'Fonts'
			//---------------------------------------------
			'fonts'             => array(
				'title'    => esc_html__( 'Typography', 'rumble' ),
				'desc'     => '',
				'priority' => 200,
				'type'     => 'panel',
			),

			// Fonts - Load_fonts
			'load_fonts'        => array(
				'title' => esc_html__( 'Load fonts', 'rumble' ),
				'desc'  => wp_kses_data( __( 'Specify fonts to load when theme start. You can use them in the base theme elements: headers, text, menu, links, input fields, etc.', 'rumble' ) )
						. '<br>'
						. wp_kses_data( __( 'Attention! Press "Refresh" button to reload preview area after the all fonts are changed', 'rumble' ) ),
				'type'  => 'section',
			),
			'load_fonts_subset' => array(
				'title'   => esc_html__( 'Google fonts subsets', 'rumble' ),
				'desc'    => wp_kses_data( __( 'Specify comma separated list of the subsets which will be load from Google fonts', 'rumble' ) )
						. '<br>'
						. wp_kses_data( __( 'Available subsets are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese', 'rumble' ) ),
				'class'   => 'rumble_column-1_3 rumble_new_row',
				'refresh' => false,
				'std'     => '$rumble_get_load_fonts_subset',
				'type'    => 'text',
			),
		);

		for ( $i = 1; $i <= rumble_get_theme_setting( 'max_load_fonts' ); $i++ ) {
			if ( rumble_get_value_gp( 'page' ) != 'theme_options' ) {
				$fonts[ "load_fonts-{$i}-info" ] = array(
					// Translators: Add font's number - 'Font 1', 'Font 2', etc
					'title' => esc_html( sprintf( __( 'Font %s', 'rumble' ), $i ) ),
					'desc'  => '',
					'type'  => 'info',
				);
			}
			$fonts[ "load_fonts-{$i}-name" ]   = array(
				'title'   => esc_html__( 'Font name', 'rumble' ),
				'desc'    => '',
				'class'   => 'rumble_column-1_3 rumble_new_row',
				'refresh' => false,
				'std'     => '$rumble_get_load_fonts_option',
				'type'    => 'text',
			);
			$fonts[ "load_fonts-{$i}-family" ] = array(
				'title'   => esc_html__( 'Font family', 'rumble' ),
				'desc'    => 1 == $i
							? wp_kses_data( __( 'Select font family to use it if font above is not available', 'rumble' ) )
							: '',
				'class'   => 'rumble_column-1_3',
				'refresh' => false,
				'std'     => '$rumble_get_load_fonts_option',
				'options' => array(
					'inherit'    => esc_html__( 'Inherit', 'rumble' ),
					'serif'      => esc_html__( 'serif', 'rumble' ),
					'sans-serif' => esc_html__( 'sans-serif', 'rumble' ),
					'monospace'  => esc_html__( 'monospace', 'rumble' ),
					'cursive'    => esc_html__( 'cursive', 'rumble' ),
					'fantasy'    => esc_html__( 'fantasy', 'rumble' ),
				),
				'type'    => 'select',
			);
			$fonts[ "load_fonts-{$i}-styles" ] = array(
				'title'   => esc_html__( 'Font styles', 'rumble' ),
				'desc'    => 1 == $i
							? wp_kses_data( __( 'Font styles used only for the Google fonts. This is a comma separated list of the font weight and styles. For example: 400,400italic,700', 'rumble' ) )
								. '<br>'
								. wp_kses_data( __( 'Attention! Each weight and style increase download size! Specify only used weights and styles.', 'rumble' ) )
							: '',
				'class'   => 'rumble_column-1_3',
				'refresh' => false,
				'std'     => '$rumble_get_load_fonts_option',
				'type'    => 'text',
			);
		}
		$fonts['load_fonts_end'] = array(
			'type' => 'section_end',
		);

		// Fonts - H1..6, P, Info, Menu, etc.
		$theme_fonts = rumble_get_theme_fonts();
		foreach ( $theme_fonts as $tag => $v ) {
			$fonts[ "{$tag}_section" ] = array(
				'title' => ! empty( $v['title'] )
								? $v['title']
								// Translators: Add tag's name to make title 'H1 settings', 'P settings', etc.
								: esc_html( sprintf( __( '%s settings', 'rumble' ), $tag ) ),
				'desc'  => ! empty( $v['description'] )
								? $v['description']
								// Translators: Add tag's name to make description
								: wp_kses_post( sprintf( __( 'Font settings of the "%s" tag.', 'rumble' ), $tag ) ),
				'type'  => 'section',
			);

			foreach ( $v as $css_prop => $css_value ) {
				if ( in_array( $css_prop, array( 'title', 'description' ) ) ) {
					continue;
				}
				$options    = '';
				$type       = 'text';
				$load_order = 1;
				$title      = ucfirst( str_replace( '-', ' ', $css_prop ) );
				if ( 'font-family' == $css_prop ) {
					$type       = 'select';
					$options    = array();
					$load_order = 2;        // Load this option's value after all options are loaded (use option 'load_fonts' to build fonts list)
				} elseif ( 'font-weight' == $css_prop ) {
					$type    = 'select';
					$options = array(
						'inherit' => esc_html__( 'Inherit', 'rumble' ),
						'100'     => esc_html__( '100 (Light)', 'rumble' ),
						'200'     => esc_html__( '200 (Light)', 'rumble' ),
						'300'     => esc_html__( '300 (Thin)', 'rumble' ),
						'400'     => esc_html__( '400 (Normal)', 'rumble' ),
						'500'     => esc_html__( '500 (Semibold)', 'rumble' ),
						'600'     => esc_html__( '600 (Semibold)', 'rumble' ),
						'700'     => esc_html__( '700 (Bold)', 'rumble' ),
						'800'     => esc_html__( '800 (Black)', 'rumble' ),
						'900'     => esc_html__( '900 (Black)', 'rumble' ),
					);
				} elseif ( 'font-style' == $css_prop ) {
					$type    = 'select';
					$options = array(
						'inherit' => esc_html__( 'Inherit', 'rumble' ),
						'normal'  => esc_html__( 'Normal', 'rumble' ),
						'italic'  => esc_html__( 'Italic', 'rumble' ),
					);
				} elseif ( 'text-decoration' == $css_prop ) {
					$type    = 'select';
					$options = array(
						'inherit'      => esc_html__( 'Inherit', 'rumble' ),
						'none'         => esc_html__( 'None', 'rumble' ),
						'underline'    => esc_html__( 'Underline', 'rumble' ),
						'overline'     => esc_html__( 'Overline', 'rumble' ),
						'line-through' => esc_html__( 'Line-through', 'rumble' ),
					);
				} elseif ( 'text-transform' == $css_prop ) {
					$type    = 'select';
					$options = array(
						'inherit'    => esc_html__( 'Inherit', 'rumble' ),
						'none'       => esc_html__( 'None', 'rumble' ),
						'uppercase'  => esc_html__( 'Uppercase', 'rumble' ),
						'lowercase'  => esc_html__( 'Lowercase', 'rumble' ),
						'capitalize' => esc_html__( 'Capitalize', 'rumble' ),
					);
				}
				$fonts[ "{$tag}_{$css_prop}" ] = array(
					'title'      => $title,
					'desc'       => '',
					'class'      => 'rumble_column-1_5',
					'refresh'    => false,
					'load_order' => $load_order,
					'std'        => '$rumble_get_theme_fonts_option',
					'options'    => $options,
					'type'       => $type,
				);
			}

			$fonts[ "{$tag}_section_end" ] = array(
				'type' => 'section_end',
			);
		}

		$fonts['fonts_end'] = array(
			'type' => 'panel_end',
		);

		// Add fonts parameters to Theme Options
		rumble_storage_set_array_before( 'options', 'panel_colors', $fonts );

		// Add Header Video if WP version < 4.7
		// -----------------------------------------------------
		if ( ! function_exists( 'get_header_video_url' ) ) {
			rumble_storage_set_array_after(
				'options', 'header_image_override', 'header_video', array(
					'title'    => esc_html__( 'Header video', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select video to use it as background for the header', 'rumble' ) ),
					'override' => array(
						'mode'    => 'page',
						'section' => esc_html__( 'Header', 'rumble' ),
					),
					'std'      => '',
					'type'     => 'video',
				)
			);
		}

		// Add option 'logo' if WP version < 4.5
		// or 'custom_logo' if current page is not 'Customize'
		// ------------------------------------------------------
		if ( ! function_exists( 'the_custom_logo' ) || ! rumble_check_current_url( 'customize.php' ) ) {
			rumble_storage_set_array_before(
				'options', 'logo_retina', function_exists( 'the_custom_logo' ) ? 'custom_logo' : 'logo', array(
					'title'    => esc_html__( 'Logo', 'rumble' ),
					'desc'     => wp_kses_data( __( 'Select or upload the site logo', 'rumble' ) ),
					'class'    => 'rumble_column-1_2 rumble_new_row',
					'priority' => 60,
					'std'      => '',
					'qsetup'   => esc_html__( 'General', 'rumble' ),
					'type'     => 'image',
				)
			);
		}

	}
}


// Returns a list of options that can be overridden for CPT
if ( ! function_exists( 'rumble_options_get_list_cpt_options' ) ) {
	function rumble_options_get_list_cpt_options( $cpt, $title = '' ) {
		if ( empty( $title ) ) {
			$title = ucfirst( $cpt );
		}
		return array(
			"content_info_{$cpt}"           => array(
				'title' => esc_html__( 'Content', 'rumble' ),
				'desc'  => '',
				'type'  => 'info',
			),
			"body_style_{$cpt}"             => array(
				'title'    => esc_html__( 'Body style', 'rumble' ),
				'desc'     => wp_kses_data( __( 'Select width of the body content', 'rumble' ) ),
				'std'      => 'inherit',
				'options'  => rumble_get_list_body_styles( true ),
				'type'     => 'select',
			),
			"boxed_bg_image_{$cpt}"         => array(
				'title'      => esc_html__( 'Boxed bg image', 'rumble' ),
				'desc'       => wp_kses_data( __( 'Select or upload image, used as background in the boxed body', 'rumble' ) ),
				'dependency' => array(
					"body_style_{$cpt}" => array( 'boxed' ),
				),
				'std'        => 'inherit',
				'type'       => 'image',
			),
			"header_info_{$cpt}"            => array(
				'title' => esc_html__( 'Header', 'rumble' ),
				'desc'  => '',
				'type'  => 'info',
			),
			"header_type_{$cpt}"            => array(
				'title'   => esc_html__( 'Header style', 'rumble' ),
				'desc'    => wp_kses_data( __( 'Choose whether to use the default header or header Layouts (available only if the ThemeREX Addons is activated)', 'rumble' ) ),
				'std'     => 'inherit',
				'options' => rumble_get_list_header_footer_types( true ),
				'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
			),
			"header_style_{$cpt}"           => array(
				'title'      => esc_html__( 'Select custom layout', 'rumble' ),
				// Translators: Add CPT name to the description
				'desc'       => wp_kses_data( sprintf( __( 'Select custom layout to display the site header on the %s pages', 'rumble' ), $title ) ),
				'dependency' => array(
					"header_type_{$cpt}" => array( 'custom' ),
				),
				'std'        => 'inherit',
				'options'    => array(),
				'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'select',
			),
			"header_position_{$cpt}"        => array(
				'title'   => esc_html__( 'Header position', 'rumble' ),
				// Translators: Add CPT name to the description
				'desc'    => wp_kses_data( sprintf( __( 'Select position to display the site header on the %s pages', 'rumble' ), $title ) ),
				'std'     => 'inherit',
				'options' => array(),
				'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
			),
			"header_image_override_{$cpt}"  => array(
				'title'   => esc_html__( 'Header image override', 'rumble' ),
				'desc'    => wp_kses_data( __( "Allow override the header image with the post's featured image", 'rumble' ) ),
				'std'     => 'inherit',
				'options' => array(
					'inherit' => esc_html__( 'Inherit', 'rumble' ),
					1         => esc_html__( 'Yes', 'rumble' ),
					0         => esc_html__( 'No', 'rumble' ),
				),
				'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
			),
			"header_widgets_{$cpt}"         => array(
				'title'   => esc_html__( 'Header widgets', 'rumble' ),
				// Translators: Add CPT name to the description
				'desc'    => wp_kses_data( sprintf( __( 'Select set of widgets to show in the header on the %s pages', 'rumble' ), $title ) ),
				'std'     => 'hide',
				'options' => array(),
				'type'    => 'select',
			),

			"sidebar_info_{$cpt}"           => array(
				'title' => esc_html__( 'Sidebar', 'rumble' ),
				'desc'  => '',
				'type'  => 'info',
			),
			"sidebar_position_{$cpt}"       => array(
				'title'   => sprintf( __( 'Sidebar position on the %s list', 'rumble' ), $title ),
				// Translators: Add CPT name to the description
				'desc'    => wp_kses_data( sprintf( __( 'Select position to show sidebar on the %s list', 'rumble' ), $title ) ),
				'std'     => 'right',
				'options' => array(),
				'type'    => 'switch',
			),
			"sidebar_position_ss_{$cpt}"=> array(
				'title'    => sprintf( __( 'Sidebar position on the %s list on the small screen', 'rumble' ), $title ),
				'desc'     => wp_kses_data( __( 'Select position to move sidebar on the small screen - above or below the content', 'rumble' ) ),
				'std'      => 'below',
				'dependency' => array(
					"sidebar_position_{$cpt}" => array( '^hide' ),
				),
				'options'  => array(),
				'type'     => 'switch',
			),
			"sidebar_widgets_{$cpt}"        => array(
				'title'      => sprintf( esc_html__( 'Sidebar widgets on the %s list', 'rumble' ), $title ),
				// Translators: Add CPT name to the description
				'desc'       => wp_kses_data( sprintf( __( 'Select sidebar to show on the %s list', 'rumble' ), $title ) ),
				'dependency' => array(
					"sidebar_position_{$cpt}" => array( '^hide' ),
				),
				'std'        => 'hide',
				'options'    => array(),
				'type'       => 'select',
			),
			"sidebar_position_single_{$cpt}"       => array(
				'title'   => sprintf( esc_html__( 'Sidebar position on the single post', 'rumble' ), $title ),
				// Translators: Add CPT name to the description
				'desc'    => wp_kses_data( sprintf( __( 'Select position to show sidebar on the single posts of the %s', 'rumble' ), $title ) ),
				'std'     => 'left',
				'options' => array(),
				'type'    => 'switch',
			),
			"sidebar_position_ss_single_{$cpt}"=> array(
				'title'    => esc_html__( 'Sidebar position on the single post on the small screen', 'rumble' ),
				'desc'     => wp_kses_data( __( 'Select position to move sidebar on the small screen - above or below the content', 'rumble' ) ),
				'dependency' => array(
					"sidebar_position_single_{$cpt}" => array( '^hide' ),
				),
				'std'      => 'below',
				'options'  => array(),
				'type'     => 'switch',
			),
			"sidebar_widgets_single_{$cpt}"        => array(
				'title'      => sprintf( esc_html__( 'Sidebar widgets on the single post', 'rumble' ), $title ),
				// Translators: Add CPT name to the description
				'desc'       => wp_kses_data( sprintf( __( 'Select widgets to show in the sidebar on the single posts of the %s', 'rumble' ), $title ) ),
				'dependency' => array(
					"sidebar_position_single_{$cpt}" => array( '^hide' ),
				),
				'std'        => 'hide',
				'options'    => array(),
				'type'       => 'select',
			),
			"expand_content_{$cpt}"         => array(
				'title'   => esc_html__( 'Expand content', 'rumble' ),
				'desc'    => wp_kses_data( __( 'Expand the content width if the sidebar is hidden', 'rumble' ) ),
				'refresh' => false,
				'std'     => 'inherit',
				'options'  => rumble_get_list_checkbox_values( true ),
				'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
			),
			"expand_content_single_{$cpt}"         => array(
				'title'   => esc_html__( 'Expand content on the single post', 'rumble' ),
				'desc'    => wp_kses_data( __( 'Expand the content width on the single post if the sidebar is hidden', 'rumble' ) ),
				'refresh' => false,
				'std'     => 'inherit',
				'options'  => rumble_get_list_checkbox_values( true ),
				'type'     => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
			),

			"footer_info_{$cpt}"            => array(
				'title' => esc_html__( 'Footer', 'rumble' ),
				'desc'  => '',
				'type'  => 'info',
			),
			"footer_type_{$cpt}"            => array(
				'title'   => esc_html__( 'Footer style', 'rumble' ),
				'desc'    => wp_kses_data( __( 'Choose whether to use the default footer or footer Layouts (available only if the ThemeREX Addons is activated)', 'rumble' ) ),
				'std'     => 'default',
				'options' => rumble_get_list_header_footer_types( true ),
				'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'switch',
			),
			"footer_style_{$cpt}"           => array(
				'title'      => esc_html__( 'Select custom layout', 'rumble' ),
				'desc'       => wp_kses_data( __( 'Select custom layout to display the site footer', 'rumble' ) ),
				'std'        => 'inherit',
				'dependency' => array(
					"footer_type_{$cpt}" => array( 'custom' ),
				),
				'options'    => array(),
				'type'       => RUMBLE_THEME_FREE ? 'hidden' : 'select',
			),
			"footer_widgets_{$cpt}"         => array(
				'title'      => esc_html__( 'Footer widgets', 'rumble' ),
				'desc'       => wp_kses_data( __( 'Select set of widgets to show in the footer', 'rumble' ) ),
				'dependency' => array(
					"footer_type_{$cpt}" => array( 'default' ),
				),
				'std'        => 'footer_widgets',
				'options'    => array(),
				'type'       => 'select',
			),
			"footer_columns_{$cpt}"         => array(
				'title'      => esc_html__( 'Footer columns', 'rumble' ),
				'desc'       => wp_kses_data( __( 'Select number columns to show widgets in the footer. If 0 - autodetect by the widgets count', 'rumble' ) ),
				'dependency' => array(
					"footer_type_{$cpt}"    => array( 'default' ),
					"footer_widgets_{$cpt}" => array( '^hide' ),
				),
				'std'        => 0,
				'options'    => rumble_get_list_range( 0, 6 ),
				'type'       => 'select',
			),
			"footer_wide_{$cpt}"            => array(
				'title'      => esc_html__( 'Footer fullwidth', 'rumble' ),
				'desc'       => wp_kses_data( __( 'Do you want to stretch the footer to the entire window width?', 'rumble' ) ),
				'dependency' => array(
					"footer_type_{$cpt}" => array( 'default' ),
				),
				'std'        => 0,
				'type'       => 'checkbox',
			),

			"widgets_info_{$cpt}"           => array(
				'title' => esc_html__( 'Additional panels', 'rumble' ),
				'desc'  => '',
				'type'  => RUMBLE_THEME_FREE ? 'hidden' : 'info',
			),
			"widgets_above_page_{$cpt}"     => array(
				'title'   => esc_html__( 'Widgets at the top of the page', 'rumble' ),
				'desc'    => wp_kses_data( __( 'Select widgets to show at the top of the page (above content and sidebar)', 'rumble' ) ),
				'std'     => 'hide',
				'options' => array(),
				'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'select',
			),
			"widgets_above_content_{$cpt}"  => array(
				'title'   => esc_html__( 'Widgets above the content', 'rumble' ),
				'desc'    => wp_kses_data( __( 'Select widgets to show at the beginning of the content area', 'rumble' ) ),
				'std'     => 'hide',
				'options' => array(),
				'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'select',
			),
			"widgets_below_content_{$cpt}"  => array(
				'title'   => esc_html__( 'Widgets below the content', 'rumble' ),
				'desc'    => wp_kses_data( __( 'Select widgets to show at the ending of the content area', 'rumble' ) ),
				'std'     => 'hide',
				'options' => array(),
				'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'select',
			),
			"widgets_below_page_{$cpt}"     => array(
				'title'   => esc_html__( 'Widgets at the bottom of the page', 'rumble' ),
				'desc'    => wp_kses_data( __( 'Select widgets to show at the bottom of the page (below content and sidebar)', 'rumble' ) ),
				'std'     => 'hide',
				'options' => array(),
				'type'    => RUMBLE_THEME_FREE ? 'hidden' : 'select',
			),
		);
	}
}


// Return lists with choises when its need in the admin mode
if ( ! function_exists( 'rumble_options_get_list_choises' ) ) {
	add_filter( 'rumble_filter_options_get_list_choises', 'rumble_options_get_list_choises', 10, 2 );
	function rumble_options_get_list_choises( $list, $id ) {
		if ( is_array( $list ) && count( $list ) == 0 ) {
			if ( strpos( $id, 'header_style' ) === 0 ) {
				$list = rumble_get_list_header_styles( strpos( $id, 'header_style_' ) === 0 );
			} elseif ( strpos( $id, 'header_position' ) === 0 ) {
				$list = rumble_get_list_header_positions( strpos( $id, 'header_position_' ) === 0 );
			} elseif ( strpos( $id, 'header_widgets' ) === 0 ) {
				$list = rumble_get_list_sidebars( strpos( $id, 'header_widgets_' ) === 0, true );
			} elseif ( strpos( $id, '_scheme' ) > 0 ) {
				$list = rumble_get_list_schemes( 'color_scheme' != $id );
			} elseif ( strpos( $id, 'sidebar_widgets' ) === 0 ) {
				$list = rumble_get_list_sidebars( 'sidebar_widgets_single' != $id && ( strpos( $id, 'sidebar_widgets_' ) === 0 || strpos( $id, 'sidebar_widgets_single_' ) === 0 ), true );
			} elseif ( strpos( $id, 'sidebar_position_ss' ) === 0 ) {
				$list = rumble_get_list_sidebars_positions_ss( strpos( $id, 'sidebar_position_ss_' ) === 0 );
			} elseif ( strpos( $id, 'sidebar_position' ) === 0 ) {
				$list = rumble_get_list_sidebars_positions( strpos( $id, 'sidebar_position_' ) === 0 );
			} elseif ( strpos( $id, 'widgets_above_page' ) === 0 ) {
				$list = rumble_get_list_sidebars( strpos( $id, 'widgets_above_page_' ) === 0, true );
			} elseif ( strpos( $id, 'widgets_above_content' ) === 0 ) {
				$list = rumble_get_list_sidebars( strpos( $id, 'widgets_above_content_' ) === 0, true );
			} elseif ( strpos( $id, 'widgets_below_page' ) === 0 ) {
				$list = rumble_get_list_sidebars( strpos( $id, 'widgets_below_page_' ) === 0, true );
			} elseif ( strpos( $id, 'widgets_below_content' ) === 0 ) {
				$list = rumble_get_list_sidebars( strpos( $id, 'widgets_below_content_' ) === 0, true );
			} elseif ( strpos( $id, 'footer_style' ) === 0 ) {
				$list = rumble_get_list_footer_styles( strpos( $id, 'footer_style_' ) === 0 );
			} elseif ( strpos( $id, 'footer_widgets' ) === 0 ) {
				$list = rumble_get_list_sidebars( strpos( $id, 'footer_widgets_' ) === 0, true );
			} elseif ( strpos( $id, 'blog_style' ) === 0 ) {
				$list = rumble_get_list_blog_styles( strpos( $id, 'blog_style_' ) === 0 );
			} elseif ( strpos( $id, 'post_type' ) === 0 ) {
				$list = rumble_get_list_posts_types();
			} elseif ( strpos( $id, 'parent_cat' ) === 0 ) {
				$list = rumble_array_merge( array( 0 => esc_html__( '- Select category -', 'rumble' ) ), rumble_get_list_categories() );
			} elseif ( strpos( $id, 'blog_animation' ) === 0 ) {
				$list = rumble_get_list_animations_in();
			} elseif ( 'color_scheme_editor' == $id ) {
				$list = rumble_get_list_schemes();
			} elseif ( strpos( $id, '_font-family' ) > 0 ) {
				$list = rumble_get_list_load_fonts( true );
			}
		}
		return $list;
	}
}
